'use strict';

var web3_js = require('@solana/web3.js');
require('@solana-program/token');
var resolvers = require('@tensor-foundation/resolvers');

var __getOwnPropNames = Object.getOwnPropertyNames;
var __esm = (fn, res) => function __init() {
  return fn && (res = (0, fn[__getOwnPropNames(fn)[0]])(fn = 0)), res;
};

// env-shim.ts
var init_env_shim = __esm({
  "env-shim.ts"() {
  }
});

// src/index.ts
init_env_shim();

// src/generated/accounts/assetDepositReceipt.ts
init_env_shim();

// src/generated/pdas/assetDepositReceipt.ts
init_env_shim();
async function findAssetDepositReceiptPda(seeds, config = {}) {
  const {
    programAddress = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("nft_receipt"),
      web3_js.getAddressEncoder().encode(seeds.asset),
      web3_js.getAddressEncoder().encode(seeds.pool)
    ]
  });
}

// src/generated/pdas/nftDepositReceipt.ts
init_env_shim();
async function findNftDepositReceiptPda(seeds, config = {}) {
  const {
    programAddress = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("nft_receipt"),
      web3_js.getAddressEncoder().encode(seeds.mint),
      web3_js.getAddressEncoder().encode(seeds.pool)
    ]
  });
}

// src/generated/pdas/pool.ts
init_env_shim();
async function findPoolPda(seeds, config = {}) {
  const {
    programAddress = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("pool"),
      web3_js.getAddressEncoder().encode(seeds.owner),
      web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32).encode(seeds.poolId)
    ]
  });
}

// src/generated/accounts/assetDepositReceipt.ts
var ASSET_DEPOSIT_RECEIPT_DISCRIMINATOR = new Uint8Array([
  147,
  18,
  99,
  58,
  249,
  8,
  196,
  221
]);
function getAssetDepositReceiptDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    ASSET_DEPOSIT_RECEIPT_DISCRIMINATOR
  );
}
function getAssetDepositReceiptEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["bump", web3_js.getU8Encoder()],
      ["asset", web3_js.getAddressEncoder()],
      ["pool", web3_js.getAddressEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: ASSET_DEPOSIT_RECEIPT_DISCRIMINATOR
    })
  );
}
function getAssetDepositReceiptDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["bump", web3_js.getU8Decoder()],
    ["asset", web3_js.getAddressDecoder()],
    ["pool", web3_js.getAddressDecoder()]
  ]);
}
function getAssetDepositReceiptCodec() {
  return web3_js.combineCodec(
    getAssetDepositReceiptEncoder(),
    getAssetDepositReceiptDecoder()
  );
}
function decodeAssetDepositReceipt(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getAssetDepositReceiptDecoder()
  );
}
async function fetchAssetDepositReceipt(rpc, address4, config) {
  const maybeAccount = await fetchMaybeAssetDepositReceipt(
    rpc,
    address4,
    config
  );
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeAssetDepositReceipt(rpc, address4, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address4, config);
  return decodeAssetDepositReceipt(maybeAccount);
}
async function fetchAllAssetDepositReceipt(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeAssetDepositReceipt(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeAssetDepositReceipt(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeAssetDepositReceipt(maybeAccount)
  );
}
function getAssetDepositReceiptSize() {
  return 73;
}
async function fetchAssetDepositReceiptFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeAssetDepositReceiptFromSeeds(
    rpc,
    seeds,
    config
  );
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeAssetDepositReceiptFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address4] = await findAssetDepositReceiptPda(seeds, { programAddress });
  return await fetchMaybeAssetDepositReceipt(rpc, address4, fetchConfig);
}

// src/generated/accounts/nftDepositReceipt.ts
init_env_shim();
var NFT_DEPOSIT_RECEIPT_DISCRIMINATOR = new Uint8Array([
  206,
  255,
  132,
  254,
  67,
  78,
  62,
  96
]);
function getNftDepositReceiptDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    NFT_DEPOSIT_RECEIPT_DISCRIMINATOR
  );
}
function getNftDepositReceiptEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["bump", web3_js.getU8Encoder()],
      ["mint", web3_js.getAddressEncoder()],
      ["pool", web3_js.getAddressEncoder()]
    ]),
    (value) => ({ ...value, discriminator: NFT_DEPOSIT_RECEIPT_DISCRIMINATOR })
  );
}
function getNftDepositReceiptDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["bump", web3_js.getU8Decoder()],
    ["mint", web3_js.getAddressDecoder()],
    ["pool", web3_js.getAddressDecoder()]
  ]);
}
function getNftDepositReceiptCodec() {
  return web3_js.combineCodec(
    getNftDepositReceiptEncoder(),
    getNftDepositReceiptDecoder()
  );
}
function decodeNftDepositReceipt(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getNftDepositReceiptDecoder()
  );
}
async function fetchNftDepositReceipt(rpc, address4, config) {
  const maybeAccount = await fetchMaybeNftDepositReceipt(rpc, address4, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeNftDepositReceipt(rpc, address4, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address4, config);
  return decodeNftDepositReceipt(maybeAccount);
}
async function fetchAllNftDepositReceipt(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeNftDepositReceipt(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeNftDepositReceipt(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeNftDepositReceipt(maybeAccount)
  );
}
function getNftDepositReceiptSize() {
  return 73;
}
async function fetchNftDepositReceiptFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeNftDepositReceiptFromSeeds(
    rpc,
    seeds,
    config
  );
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeNftDepositReceiptFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address4] = await findNftDepositReceiptPda(seeds, { programAddress });
  return await fetchMaybeNftDepositReceipt(rpc, address4, fetchConfig);
}

// src/generated/accounts/pool.ts
init_env_shim();

// src/hooked/currency.ts
init_env_shim();
var SOL_ADDRESS = web3_js.address("11111111111111111111111111111111");
var isSol = (currency) => currency === SOL_ADDRESS;
var solCurrency = () => SOL_ADDRESS;
var getCurrencyEncoder = () => web3_js.getAddressEncoder();
var getCurrencyDecoder = () => web3_js.getAddressDecoder();
var getCurrencyCodec = () => web3_js.combineCodec(getCurrencyEncoder(), getCurrencyDecoder());

// src/hooked/helpers.ts
init_env_shim();

// src/hooked/nullableAddress.ts
init_env_shim();
var DEFAULT_ADDRESS = web3_js.address("11111111111111111111111111111111");
var getNullableAddressEncoder = () => web3_js.createEncoder({
  fixedSize: 32,
  write(value, bytes, offset) {
    if (value === null) {
      bytes.set(web3_js.getAddressEncoder().encode(DEFAULT_ADDRESS), offset);
    } else {
      bytes.set(web3_js.getAddressEncoder().encode(value), offset);
    }
    return offset + 32;
  }
});
var getNullableAddressDecoder = () => web3_js.createDecoder({
  fixedSize: 32,
  read(bytes, offset) {
    if (web3_js.getAddressDecoder().decode(bytes, offset) === DEFAULT_ADDRESS) {
      return [null, offset + 32];
    } else {
      return [web3_js.getAddressDecoder().decode(bytes, offset), offset + 32];
    }
  }
});
var getNullableAddressCodec = () => web3_js.combineCodec(getNullableAddressEncoder(), getNullableAddressDecoder());

// src/hooked/helpers.ts
var BASIS_POINTS = 10000n;
var BASIS_POINTS_DECIMAL_OFFSET = 4;
var BID_AMOUNT_LIMIT = 1e3;
function calculateAmountForQuantity({
  pool,
  quantity,
  side
}) {
  if (quantity < 1) return 0;
  if (side === 1 /* Sell */) {
    if (pool.config.poolType === 1 /* NFT */) return 0;
    const excludeMMFee = pool.config.poolType === 2 /* Trade */ && !pool.config.mmCompoundFees;
    if (pool.config.curveType === 0 /* Linear */) {
      const currentPrice = calculatePrice({
        pool,
        side: 1 /* Sell */,
        royaltyFeeBps: 0,
        extraOffset: 0,
        excludeMMFee
      });
      if (quantity === 1) return currentPrice;
      const maxPossibleBidsBeforeZero = pool.config.delta <= 0n ? quantity : 1 + Number(BigInt(currentPrice) / pool.config.delta);
      quantity = Math.min(quantity, maxPossibleBidsBeforeZero);
      const bases = currentPrice * quantity;
      const deltas = Number(pool.config.delta) * (quantity * (quantity - 1)) / 2;
      return bases - deltas;
    } else {
      let totalPrice = 0;
      let i = 0;
      while (quantity > 0) {
        totalPrice += calculatePrice({
          pool,
          side: 1 /* Sell */,
          royaltyFeeBps: 0,
          extraOffset: i,
          excludeMMFee
        });
        quantity -= 1;
        if (totalPrice === 0) break;
        i += 1;
      }
      return totalPrice;
    }
  } else {
    if (pool.config.poolType === 0 /* Token */) return 0;
    let totalPrice = 0;
    let i = 0;
    while (quantity > 0) {
      totalPrice += calculatePrice({
        pool,
        side: 0 /* Buy */,
        royaltyFeeBps: 0,
        extraOffset: i,
        excludeMMFee: false
      });
      quantity -= 1;
      i += 1;
    }
    return totalPrice;
  }
}
function getAmountOfBids({
  pool,
  availableLamports
}) {
  if (pool.config.poolType === 1 /* NFT */) return 0;
  let amountOfBidsWithoutMaxCount;
  const excludeMMFee = pool.config.poolType === 2 /* Trade */ && !pool.config.mmCompoundFees;
  if (pool.config.curveType === 0 /* Linear */) {
    const currentPrice = calculatePrice({
      pool,
      side: 1 /* Sell */,
      royaltyFeeBps: 0,
      extraOffset: 0,
      excludeMMFee
    });
    if (currentPrice < 0) return 0;
    let maxPossibleBidsBeforeZero = pool.config.delta <= 0n ? BID_AMOUNT_LIMIT : 1 + Number(BigInt(currentPrice) / pool.config.delta);
    maxPossibleBidsBeforeZero = Math.min(
      maxPossibleBidsBeforeZero,
      BID_AMOUNT_LIMIT
    );
    let bidCount = 0;
    let accumulatedPrice = 0n;
    while (accumulatedPrice < BigInt(availableLamports) && bidCount < maxPossibleBidsBeforeZero + 1) {
      const price = calculatePrice({
        pool,
        side: 1 /* Sell */,
        royaltyFeeBps: 0,
        extraOffset: bidCount,
        excludeMMFee
      });
      accumulatedPrice += BigInt(price);
      bidCount += 1;
    }
    amountOfBidsWithoutMaxCount = Math.min(
      bidCount - 1,
      maxPossibleBidsBeforeZero
    );
  } else {
    let bidCount = 0;
    let accumulatedPrice = 0n;
    while (accumulatedPrice < BigInt(availableLamports) && bidCount < BID_AMOUNT_LIMIT + 1) {
      const price = calculatePrice({
        pool,
        side: 1 /* Sell */,
        royaltyFeeBps: 0,
        extraOffset: bidCount,
        excludeMMFee
      });
      accumulatedPrice += BigInt(price);
      bidCount += 1;
    }
    amountOfBidsWithoutMaxCount = bidCount - 1;
  }
  return isMaxTakerSellCountReached(pool) ? Math.min(
    amountOfBidsWithoutMaxCount,
    pool.maxTakerSellCount + pool.priceOffset
  ) : amountOfBidsWithoutMaxCount;
}
function getCurrentAskPrice({
  pool,
  royaltyFeeBps,
  extraOffset = 0,
  excludeMMFee = false
}) {
  if (pool.nftsHeld < 1) return null;
  if (isNotFulfillable({ pool, side: 0 /* Buy */ })) return null;
  return calculatePrice({
    pool,
    side: 0 /* Buy */,
    royaltyFeeBps,
    extraOffset,
    excludeMMFee
  });
}
function getCurrentBidPriceSync({
  pool,
  availableLamports,
  royaltyFeeBps,
  extraOffset = 0,
  excludeMMFee = false
}) {
  const bidPrice = calculatePrice({
    pool,
    side: 1 /* Sell */,
    royaltyFeeBps,
    extraOffset,
    excludeMMFee
  });
  if (bidPrice < 1) return 0;
  if (isNotFulfillable({ pool, side: 1 /* Sell */ })) return null;
  return availableLamports >= bidPrice ? bidPrice : null;
}
async function getCurrentBidPrice({
  rpc,
  pool,
  royaltyFeeBps,
  extraOffset = 0,
  excludeMMFee = false
}) {
  if (isNotFulfillable({ pool, side: 1 /* Sell */ })) return null;
  const bidPrice = calculatePrice({
    pool,
    side: 1 /* Sell */,
    royaltyFeeBps,
    extraOffset,
    excludeMMFee
  });
  if (bidPrice === null) return null;
  if (bidPrice < 1) return 0;
  if (!pool.sharedEscrow || pool.sharedEscrow === DEFAULT_ADDRESS)
    return pool.amount >= bidPrice ? bidPrice : null;
  const [escrowLamports, escrowDataLength] = await rpc.getAccountInfo(pool.sharedEscrow, { encoding: "base64" }).send().then((resp) => {
    const dataLength = resp.value?.data ? Buffer.from(resp.value.data[0], "base64").length : void 0;
    return [resp.value?.lamports, dataLength];
  });
  if (!escrowLamports || !escrowDataLength) return null;
  const rentExemption = await rpc.getMinimumBalanceForRentExemption(BigInt(escrowDataLength)).send();
  return BigInt(escrowLamports) - rentExemption >= bidPrice ? bidPrice : null;
}
function calculatePrice({
  pool,
  side,
  royaltyFeeBps,
  extraOffset = 0,
  excludeMMFee = false
}) {
  const extraOffsetNormalized = Math.abs(extraOffset);
  const tradePoolOffset = pool.config.poolType === 2 /* Trade */ && side === 1 /* Sell */ ? -1 : 0;
  const offset = pool.priceOffset + tradePoolOffset + (side === 1 /* Sell */ ? -extraOffsetNormalized : extraOffsetNormalized);
  const startingPrice = pool.config.startingPrice;
  const delta = pool.config.delta;
  let resultPrice;
  if (pool.config.curveType === 1 /* Exponential */) {
    const base = BASIS_POINTS + delta;
    const exponent = BigInt(Math.abs(offset));
    const [scaling, decimalOffset] = powerBpsAsBigInt_12DecimalMantissaPrecision(base, exponent);
    let resultPriceIntermediate;
    if (offset < 0) {
      const divident = startingPrice * 10n ** decimalOffset;
      const divisor = scaling;
      resultPriceIntermediate = divident / divisor + BigInt(+needsRoundingAddedBack(divident, divisor, side));
    } else {
      const divident = startingPrice * scaling;
      const divisor = 10n ** decimalOffset;
      resultPriceIntermediate = divident / divisor + BigInt(+needsRoundingAddedBack(divident, divisor, side));
    }
    resultPrice = Number(resultPriceIntermediate);
  } else {
    resultPrice = Number(startingPrice + delta * BigInt(offset));
  }
  let resultPriceIncludingMmFees;
  if (pool.config.poolType === 2 /* Trade */ && !excludeMMFee) {
    const mmFees = BigInt(resultPrice) * BigInt(pool.config.mmFeeBps ?? 0) / BASIS_POINTS;
    resultPriceIncludingMmFees = side === 1 /* Sell */ ? Number(BigInt(resultPrice) - mmFees) : Number(BigInt(resultPrice) + mmFees);
  } else {
    resultPriceIncludingMmFees = resultPrice;
  }
  let resultPriceIncludingMmFeesAndRoyalties;
  if (royaltyFeeBps === 0) return resultPriceIncludingMmFees;
  else {
    const royalties = BigInt(resultPrice) * BigInt(royaltyFeeBps) / BASIS_POINTS;
    resultPriceIncludingMmFeesAndRoyalties = side === 1 /* Sell */ ? Number(BigInt(resultPriceIncludingMmFees) - royalties) : Number(BigInt(resultPriceIncludingMmFees) + royalties);
  }
  return resultPriceIncludingMmFeesAndRoyalties;
}
function powerBpsAsBigInt_12DecimalMantissaPrecision(base, exponent) {
  let result;
  let decimalOffset = BASIS_POINTS_DECIMAL_OFFSET;
  let resultDecimalOffset = BASIS_POINTS_DECIMAL_OFFSET;
  if (exponent === 0n)
    return [1n * BASIS_POINTS, 1n * BigInt(BASIS_POINTS_DECIMAL_OFFSET)];
  if (exponent % 2n === 1n) {
    result = base;
  } else {
    result = 1n * BASIS_POINTS;
  }
  let pow = base;
  exponent /= 2n;
  while (exponent > 0n) {
    pow *= pow;
    decimalOffset *= 2;
    [pow, decimalOffset] = cutTo12MantissaDecimals(pow, decimalOffset);
    if (exponent % 2n === 1n) {
      result *= pow;
      resultDecimalOffset += decimalOffset;
      [result, resultDecimalOffset] = cutTo12MantissaDecimals(
        result,
        resultDecimalOffset
      );
    }
    exponent /= 2n;
  }
  [result, resultDecimalOffset] = cutTo12MantissaDecimals(
    result,
    resultDecimalOffset
  );
  return [result, BigInt(resultDecimalOffset)];
}
var needsRoundingAddedBack = (divident, divisor, side) => {
  const remainder = divident % divisor;
  return remainder > 0 && side === 0 /* Buy */;
};
var cutTo12MantissaDecimals = (num, decimalOffset, withRounding = true) => {
  const decimalPrecision = 12;
  const exponentLength = num.toString(10).length - decimalOffset;
  let adjustedOffset = decimalOffset;
  let adjustedNum = num;
  if (decimalOffset > decimalPrecision) {
    adjustedNum = BigInt(
      num.toString(10).slice(0, exponentLength + decimalPrecision)
    );
    adjustedOffset = adjustedNum.toString(10).length - exponentLength;
  }
  adjustedNum += withRounding ? BigInt(+(parseInt(num.toString()[decimalPrecision + 1]) > 4)) : 0n;
  return [adjustedNum, adjustedOffset];
};
function isMaxTakerSellCountReached(pool) {
  return pool.priceOffset * -1 === pool.maxTakerSellCount && pool.maxTakerSellCount !== 0 && !!pool.sharedEscrow && pool.sharedEscrow !== DEFAULT_ADDRESS;
}
var isNotFulfillable = ({
  pool,
  side
}) => {
  return (
    // can't sell into PoolType.NFT
    pool.config.poolType === 1 /* NFT */ && side === 1 /* Sell */ || // can't buy from a PoolType.Token
    pool.config.poolType === 0 /* Token */ && side === 0 /* Buy */ || // if maxTakerSellCount is reached when pool is attached to margin acc,
    // pool can't fulfill more bids
    isMaxTakerSellCountReached(pool) && side === 1 /* Sell */
  );
};

// src/hooked/nullableNumber.ts
init_env_shim();
var getNullableU16Encoder = () => web3_js.createEncoder({
  fixedSize: 2,
  write(value, bytes, offset) {
    if (value === null) {
      bytes.set(web3_js.getU16Encoder().encode(0), offset);
    } else {
      bytes.set(web3_js.getU16Encoder().encode(value), offset);
    }
    return offset + 2;
  }
});
var getNullableU16Decoder = () => web3_js.createDecoder({
  fixedSize: 2,
  read(bytes, offset) {
    if (web3_js.getU16Decoder().decode(bytes, offset) === 0) {
      return [null, offset + 2];
    } else {
      return [web3_js.getU16Decoder().decode(bytes, offset), offset + 2];
    }
  }
});
var getNullableU16Codec = () => web3_js.combineCodec(getNullableU16Encoder(), getNullableU16Decoder());

// src/hooked/resolvers.ts
init_env_shim();

// node_modules/.pnpm/@tensor-foundation+mpl-token-metadata@1.0.0-beta.1_bufferutil@4.0.8_fastestsmallesttextencode_fhlrog52xoqwrkk6nerzh6ehye/node_modules/@tensor-foundation/mpl-token-metadata/dist/src/index.mjs
init_env_shim();
var TokenStandard = /* @__PURE__ */ ((TokenStandard2) => {
  TokenStandard2[TokenStandard2["NonFungible"] = 0] = "NonFungible";
  TokenStandard2[TokenStandard2["FungibleAsset"] = 1] = "FungibleAsset";
  TokenStandard2[TokenStandard2["Fungible"] = 2] = "Fungible";
  TokenStandard2[TokenStandard2["NonFungibleEdition"] = 3] = "NonFungibleEdition";
  TokenStandard2[TokenStandard2["ProgrammableNonFungible"] = 4] = "ProgrammableNonFungible";
  TokenStandard2[TokenStandard2["ProgrammableNonFungibleEdition"] = 5] = "ProgrammableNonFungibleEdition";
  return TokenStandard2;
})(TokenStandard || {});
async function findTokenRecordPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("metadata"),
      web3_js.getAddressEncoder().encode(programAddress),
      web3_js.getAddressEncoder().encode(seeds.mint),
      web3_js.getUtf8Encoder().encode("token_record"),
      web3_js.getAddressEncoder().encode(seeds.token)
    ]
  });
}
if (process.env.NODE_ENV !== "production") ;

// src/generated/shared/index.ts
init_env_shim();
function expectSome(value) {
  if (value == null) {
    throw new Error("Expected a value but received null or undefined.");
  }
  return value;
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function expectTransactionSigner(value) {
  if (!value || !isTransactionSigner(value)) {
    throw new Error("Expected a TransactionSigner.");
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      return Object.freeze({
        address: programAddress,
        role: web3_js.AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? web3_js.AccountRole.WRITABLE : web3_js.AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? web3_js.upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && web3_js.isTransactionSigner(value);
}

// src/hooked/resolvers.ts
var resolveTakerAta = async ({
  accounts
}) => {
  return {
    value: await resolvers.findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.taker?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolvePoolIdOnCreate = (_) => {
  return new Uint8Array(32).map(() => Math.random() * 256 & 255);
};
var resolveFeeVaultPdaFromPool = async ({
  accounts
}) => {
  return {
    value: await resolvers.findFeeVaultPda({
      address: expectAddress(accounts.pool?.value)
    })
  };
};
var resolvePoolAssetReceipt = async ({
  accounts
}) => {
  return {
    value: await resolvers.findNftReceiptPda(
      {
        mint: expectAddress(accounts.asset?.value),
        state: expectAddress(accounts.pool?.value)
      },
      { programAddress: web3_js.address("TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg") }
    )
  };
};
var resolveTakerTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === TokenStandard.ProgrammableNonFungible || args.tokenStandard === TokenStandard.ProgrammableNonFungibleEdition ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.takerTa?.value)
    })
  } : { value: null };
};
var resolveUserTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === TokenStandard.ProgrammableNonFungible || args.tokenStandard === TokenStandard.ProgrammableNonFungibleEdition ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(
        accounts.takerTa?.value ?? accounts.ownerTa?.value
      )
    })
  } : { value: null };
};
var resolveEdition = async ({
  accounts
}) => {
  return {
    value: await resolvers.findEditionPda({
      mint: expectAddress(accounts.mint?.value)
    })
  };
};

// src/generated/types/authorizationDataLocal.ts
init_env_shim();
function getAuthorizationDataLocalEncoder() {
  return web3_js.getStructEncoder([
    ["payload", web3_js.getArrayEncoder(getTaggedPayloadEncoder())]
  ]);
}
function getAuthorizationDataLocalDecoder() {
  return web3_js.getStructDecoder([
    ["payload", web3_js.getArrayDecoder(getTaggedPayloadDecoder())]
  ]);
}
function getAuthorizationDataLocalCodec() {
  return web3_js.combineCodec(
    getAuthorizationDataLocalEncoder(),
    getAuthorizationDataLocalDecoder()
  );
}

// src/generated/types/buySellEvent.ts
init_env_shim();
function getBuySellEventEncoder() {
  return web3_js.getStructEncoder([
    ["currentPrice", web3_js.getU64Encoder()],
    ["takerFee", web3_js.getU64Encoder()],
    ["mmFee", web3_js.getU64Encoder()],
    ["creatorsFee", web3_js.getU64Encoder()]
  ]);
}
function getBuySellEventDecoder() {
  return web3_js.getStructDecoder([
    ["currentPrice", web3_js.getU64Decoder()],
    ["takerFee", web3_js.getU64Decoder()],
    ["mmFee", web3_js.getU64Decoder()],
    ["creatorsFee", web3_js.getU64Decoder()]
  ]);
}
function getBuySellEventCodec() {
  return web3_js.combineCodec(getBuySellEventEncoder(), getBuySellEventDecoder());
}

// src/generated/types/curveType.ts
init_env_shim();
var CurveType = /* @__PURE__ */ ((CurveType2) => {
  CurveType2[CurveType2["Linear"] = 0] = "Linear";
  CurveType2[CurveType2["Exponential"] = 1] = "Exponential";
  return CurveType2;
})(CurveType || {});
function getCurveTypeEncoder() {
  return web3_js.getEnumEncoder(CurveType);
}
function getCurveTypeDecoder() {
  return web3_js.getEnumDecoder(CurveType);
}
function getCurveTypeCodec() {
  return web3_js.combineCodec(getCurveTypeEncoder(), getCurveTypeDecoder());
}

// src/generated/types/direction.ts
init_env_shim();
var Direction = /* @__PURE__ */ ((Direction2) => {
  Direction2[Direction2["Up"] = 0] = "Up";
  Direction2[Direction2["Down"] = 1] = "Down";
  return Direction2;
})(Direction || {});
function getDirectionEncoder() {
  return web3_js.getEnumEncoder(Direction);
}
function getDirectionDecoder() {
  return web3_js.getEnumDecoder(Direction);
}
function getDirectionCodec() {
  return web3_js.combineCodec(getDirectionEncoder(), getDirectionDecoder());
}

// src/generated/types/editPoolConfig.ts
init_env_shim();
function getEditPoolConfigEncoder() {
  return web3_js.getStructEncoder([
    ["curveType", getCurveTypeEncoder()],
    ["startingPrice", web3_js.getU64Encoder()],
    ["delta", web3_js.getU64Encoder()],
    ["mmCompoundFees", web3_js.getBooleanEncoder()],
    ["mmFeeBps", getNullableU16Encoder()]
  ]);
}
function getEditPoolConfigDecoder() {
  return web3_js.getStructDecoder([
    ["curveType", getCurveTypeDecoder()],
    ["startingPrice", web3_js.getU64Decoder()],
    ["delta", web3_js.getU64Decoder()],
    ["mmCompoundFees", web3_js.getBooleanDecoder()],
    ["mmFeeBps", getNullableU16Decoder()]
  ]);
}
function getEditPoolConfigCodec() {
  return web3_js.combineCodec(getEditPoolConfigEncoder(), getEditPoolConfigDecoder());
}

// src/generated/types/payloadTypeLocal.ts
init_env_shim();
function getPayloadTypeLocalEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "Pubkey",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getAddressEncoder()])]])
    ],
    [
      "Seeds",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getSeedsVecLocalEncoder()])]
      ])
    ],
    [
      "MerkleProof",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getProofInfoLocalEncoder()])]
      ])
    ],
    [
      "Number",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getU64Encoder()])]])
    ]
  ]);
}
function getPayloadTypeLocalDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "Pubkey",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getAddressDecoder()])]])
    ],
    [
      "Seeds",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getSeedsVecLocalDecoder()])]
      ])
    ],
    [
      "MerkleProof",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getProofInfoLocalDecoder()])]
      ])
    ],
    [
      "Number",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getU64Decoder()])]])
    ]
  ]);
}
function getPayloadTypeLocalCodec() {
  return web3_js.combineCodec(
    getPayloadTypeLocalEncoder(),
    getPayloadTypeLocalDecoder()
  );
}
function payloadTypeLocal(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPayloadTypeLocal(kind, value) {
  return value.__kind === kind;
}

// src/generated/types/poolConfig.ts
init_env_shim();
function getPoolConfigEncoder() {
  return web3_js.getStructEncoder([
    ["poolType", getPoolTypeEncoder()],
    ["curveType", getCurveTypeEncoder()],
    ["startingPrice", web3_js.getU64Encoder()],
    ["delta", web3_js.getU64Encoder()],
    ["mmCompoundFees", web3_js.getBooleanEncoder()],
    ["mmFeeBps", getNullableU16Encoder()]
  ]);
}
function getPoolConfigDecoder() {
  return web3_js.getStructDecoder([
    ["poolType", getPoolTypeDecoder()],
    ["curveType", getCurveTypeDecoder()],
    ["startingPrice", web3_js.getU64Decoder()],
    ["delta", web3_js.getU64Decoder()],
    ["mmCompoundFees", web3_js.getBooleanDecoder()],
    ["mmFeeBps", getNullableU16Decoder()]
  ]);
}
function getPoolConfigCodec() {
  return web3_js.combineCodec(getPoolConfigEncoder(), getPoolConfigDecoder());
}

// src/generated/types/poolStats.ts
init_env_shim();
function getPoolStatsEncoder() {
  return web3_js.getStructEncoder([
    ["takerSellCount", web3_js.getU32Encoder()],
    ["takerBuyCount", web3_js.getU32Encoder()],
    ["accumulatedMmProfit", web3_js.getU64Encoder()]
  ]);
}
function getPoolStatsDecoder() {
  return web3_js.getStructDecoder([
    ["takerSellCount", web3_js.getU32Decoder()],
    ["takerBuyCount", web3_js.getU32Decoder()],
    ["accumulatedMmProfit", web3_js.getU64Decoder()]
  ]);
}
function getPoolStatsCodec() {
  return web3_js.combineCodec(getPoolStatsEncoder(), getPoolStatsDecoder());
}

// src/generated/types/poolType.ts
init_env_shim();
var PoolType = /* @__PURE__ */ ((PoolType2) => {
  PoolType2[PoolType2["Token"] = 0] = "Token";
  PoolType2[PoolType2["NFT"] = 1] = "NFT";
  PoolType2[PoolType2["Trade"] = 2] = "Trade";
  return PoolType2;
})(PoolType || {});
function getPoolTypeEncoder() {
  return web3_js.getEnumEncoder(PoolType);
}
function getPoolTypeDecoder() {
  return web3_js.getEnumDecoder(PoolType);
}
function getPoolTypeCodec() {
  return web3_js.combineCodec(getPoolTypeEncoder(), getPoolTypeDecoder());
}

// src/generated/types/proofInfoLocal.ts
init_env_shim();
function getProofInfoLocalEncoder() {
  return web3_js.getStructEncoder([
    ["proof", web3_js.getArrayEncoder(web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32))]
  ]);
}
function getProofInfoLocalDecoder() {
  return web3_js.getStructDecoder([
    ["proof", web3_js.getArrayDecoder(web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32))]
  ]);
}
function getProofInfoLocalCodec() {
  return web3_js.combineCodec(getProofInfoLocalEncoder(), getProofInfoLocalDecoder());
}

// src/generated/types/seedsVecLocal.ts
init_env_shim();
function getSeedsVecLocalEncoder() {
  return web3_js.getStructEncoder([
    [
      "seeds",
      web3_js.getArrayEncoder(web3_js.addEncoderSizePrefix(web3_js.getBytesEncoder(), web3_js.getU32Encoder()))
    ]
  ]);
}
function getSeedsVecLocalDecoder() {
  return web3_js.getStructDecoder([
    [
      "seeds",
      web3_js.getArrayDecoder(web3_js.addDecoderSizePrefix(web3_js.getBytesDecoder(), web3_js.getU32Decoder()))
    ]
  ]);
}
function getSeedsVecLocalCodec() {
  return web3_js.combineCodec(getSeedsVecLocalEncoder(), getSeedsVecLocalDecoder());
}

// src/generated/types/taggedPayload.ts
init_env_shim();
function getTaggedPayloadEncoder() {
  return web3_js.getStructEncoder([
    ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["payload", getPayloadTypeLocalEncoder()]
  ]);
}
function getTaggedPayloadDecoder() {
  return web3_js.getStructDecoder([
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["payload", getPayloadTypeLocalDecoder()]
  ]);
}
function getTaggedPayloadCodec() {
  return web3_js.combineCodec(getTaggedPayloadEncoder(), getTaggedPayloadDecoder());
}

// src/generated/types/takerSide.ts
init_env_shim();
var TakerSide = /* @__PURE__ */ ((TakerSide2) => {
  TakerSide2[TakerSide2["Buy"] = 0] = "Buy";
  TakerSide2[TakerSide2["Sell"] = 1] = "Sell";
  return TakerSide2;
})(TakerSide || {});
function getTakerSideEncoder() {
  return web3_js.getEnumEncoder(TakerSide);
}
function getTakerSideDecoder() {
  return web3_js.getEnumDecoder(TakerSide);
}
function getTakerSideCodec() {
  return web3_js.combineCodec(getTakerSideEncoder(), getTakerSideDecoder());
}

// src/generated/types/tAmmEvent.ts
init_env_shim();
function getTAmmEventEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "BuySellEvent",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getBuySellEventEncoder()])]
      ])
    ]
  ]);
}
function getTAmmEventDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "BuySellEvent",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getBuySellEventDecoder()])]
      ])
    ]
  ]);
}
function getTAmmEventCodec() {
  return web3_js.combineCodec(getTAmmEventEncoder(), getTAmmEventDecoder());
}
function tAmmEvent(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isTAmmEvent(kind, value) {
  return value.__kind === kind;
}

// src/generated/types/transferDirection.ts
init_env_shim();
var TransferDirection = /* @__PURE__ */ ((TransferDirection2) => {
  TransferDirection2[TransferDirection2["IntoPool"] = 0] = "IntoPool";
  TransferDirection2[TransferDirection2["OutOfPool"] = 1] = "OutOfPool";
  return TransferDirection2;
})(TransferDirection || {});
function getTransferDirectionEncoder() {
  return web3_js.getEnumEncoder(TransferDirection);
}
function getTransferDirectionDecoder() {
  return web3_js.getEnumDecoder(TransferDirection);
}
function getTransferDirectionCodec() {
  return web3_js.combineCodec(
    getTransferDirectionEncoder(),
    getTransferDirectionDecoder()
  );
}

// src/generated/accounts/pool.ts
var POOL_DISCRIMINATOR = new Uint8Array([
  241,
  154,
  109,
  4,
  17,
  177,
  109,
  188
]);
function getPoolDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(POOL_DISCRIMINATOR);
}
function getPoolEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["version", web3_js.getU8Encoder()],
      ["bump", web3_js.getArrayEncoder(web3_js.getU8Encoder(), { size: 1 })],
      ["poolId", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["createdAt", web3_js.getI64Encoder()],
      ["updatedAt", web3_js.getI64Encoder()],
      ["expiry", web3_js.getI64Encoder()],
      ["owner", web3_js.getAddressEncoder()],
      ["whitelist", web3_js.getAddressEncoder()],
      ["rentPayer", web3_js.getAddressEncoder()],
      ["currency", getCurrencyEncoder()],
      ["amount", web3_js.getU64Encoder()],
      ["priceOffset", web3_js.getI32Encoder()],
      ["nftsHeld", web3_js.getU32Encoder()],
      ["stats", getPoolStatsEncoder()],
      ["sharedEscrow", getNullableAddressEncoder()],
      ["cosigner", getNullableAddressEncoder()],
      ["makerBroker", getNullableAddressEncoder()],
      ["maxTakerSellCount", web3_js.getU32Encoder()],
      ["config", getPoolConfigEncoder()],
      ["reserved", web3_js.getArrayEncoder(web3_js.getU8Encoder(), { size: 100 })]
    ]),
    (value) => ({ ...value, discriminator: POOL_DISCRIMINATOR })
  );
}
function getPoolDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["version", web3_js.getU8Decoder()],
    ["bump", web3_js.getArrayDecoder(web3_js.getU8Decoder(), { size: 1 })],
    ["poolId", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["createdAt", web3_js.getI64Decoder()],
    ["updatedAt", web3_js.getI64Decoder()],
    ["expiry", web3_js.getI64Decoder()],
    ["owner", web3_js.getAddressDecoder()],
    ["whitelist", web3_js.getAddressDecoder()],
    ["rentPayer", web3_js.getAddressDecoder()],
    ["currency", getCurrencyDecoder()],
    ["amount", web3_js.getU64Decoder()],
    ["priceOffset", web3_js.getI32Decoder()],
    ["nftsHeld", web3_js.getU32Decoder()],
    ["stats", getPoolStatsDecoder()],
    ["sharedEscrow", getNullableAddressDecoder()],
    ["cosigner", getNullableAddressDecoder()],
    ["makerBroker", getNullableAddressDecoder()],
    ["maxTakerSellCount", web3_js.getU32Decoder()],
    ["config", getPoolConfigDecoder()],
    ["reserved", web3_js.getArrayDecoder(web3_js.getU8Decoder(), { size: 100 })]
  ]);
}
function getPoolCodec() {
  return web3_js.combineCodec(getPoolEncoder(), getPoolDecoder());
}
function decodePool(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getPoolDecoder()
  );
}
async function fetchPool(rpc, address4, config) {
  const maybeAccount = await fetchMaybePool(rpc, address4, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybePool(rpc, address4, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address4, config);
  return decodePool(maybeAccount);
}
async function fetchAllPool(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybePool(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybePool(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodePool(maybeAccount));
}
function getPoolSize() {
  return 447;
}
async function fetchPoolFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybePoolFromSeeds(rpc, seeds, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybePoolFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address4] = await findPoolPda(seeds, { programAddress });
  return await fetchMaybePool(rpc, address4, fetchConfig);
}

// src/generated/errors/tensorAmm.ts
init_env_shim();

// src/generated/programs/tensorAmm.ts
init_env_shim();
var TENSOR_AMM_PROGRAM_ADDRESS = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
var TensorAmmAccount = /* @__PURE__ */ ((TensorAmmAccount2) => {
  TensorAmmAccount2[TensorAmmAccount2["AssetDepositReceipt"] = 0] = "AssetDepositReceipt";
  TensorAmmAccount2[TensorAmmAccount2["NftDepositReceipt"] = 1] = "NftDepositReceipt";
  TensorAmmAccount2[TensorAmmAccount2["Pool"] = 2] = "Pool";
  return TensorAmmAccount2;
})(TensorAmmAccount || {});
function identifyTensorAmmAccount(account) {
  const data = "data" in account ? account.data : account;
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([147, 18, 99, 58, 249, 8, 196, 221])
    ),
    0
  )) {
    return 0 /* AssetDepositReceipt */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([206, 255, 132, 254, 67, 78, 62, 96])
    ),
    0
  )) {
    return 1 /* NftDepositReceipt */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([241, 154, 109, 4, 17, 177, 109, 188])
    ),
    0
  )) {
    return 2 /* Pool */;
  }
  throw new Error(
    "The provided account could not be identified as a tensorAmm account."
  );
}
var TensorAmmInstruction = /* @__PURE__ */ ((TensorAmmInstruction2) => {
  TensorAmmInstruction2[TensorAmmInstruction2["TammNoop"] = 0] = "TammNoop";
  TensorAmmInstruction2[TensorAmmInstruction2["CreatePool"] = 1] = "CreatePool";
  TensorAmmInstruction2[TensorAmmInstruction2["EditPool"] = 2] = "EditPool";
  TensorAmmInstruction2[TensorAmmInstruction2["ClosePool"] = 3] = "ClosePool";
  TensorAmmInstruction2[TensorAmmInstruction2["CloseExpiredPool"] = 4] = "CloseExpiredPool";
  TensorAmmInstruction2[TensorAmmInstruction2["DepositSol"] = 5] = "DepositSol";
  TensorAmmInstruction2[TensorAmmInstruction2["WithdrawSol"] = 6] = "WithdrawSol";
  TensorAmmInstruction2[TensorAmmInstruction2["DepositNft"] = 7] = "DepositNft";
  TensorAmmInstruction2[TensorAmmInstruction2["WithdrawNft"] = 8] = "WithdrawNft";
  TensorAmmInstruction2[TensorAmmInstruction2["BuyNft"] = 9] = "BuyNft";
  TensorAmmInstruction2[TensorAmmInstruction2["SellNftTokenPool"] = 10] = "SellNftTokenPool";
  TensorAmmInstruction2[TensorAmmInstruction2["SellNftTradePool"] = 11] = "SellNftTradePool";
  TensorAmmInstruction2[TensorAmmInstruction2["DepositNftCore"] = 12] = "DepositNftCore";
  TensorAmmInstruction2[TensorAmmInstruction2["WithdrawNftCore"] = 13] = "WithdrawNftCore";
  TensorAmmInstruction2[TensorAmmInstruction2["BuyNftCore"] = 14] = "BuyNftCore";
  TensorAmmInstruction2[TensorAmmInstruction2["SellNftTokenPoolCore"] = 15] = "SellNftTokenPoolCore";
  TensorAmmInstruction2[TensorAmmInstruction2["SellNftTradePoolCore"] = 16] = "SellNftTradePoolCore";
  TensorAmmInstruction2[TensorAmmInstruction2["DepositNftT22"] = 17] = "DepositNftT22";
  TensorAmmInstruction2[TensorAmmInstruction2["WithdrawNftT22"] = 18] = "WithdrawNftT22";
  TensorAmmInstruction2[TensorAmmInstruction2["BuyNftT22"] = 19] = "BuyNftT22";
  TensorAmmInstruction2[TensorAmmInstruction2["SellNftTokenPoolT22"] = 20] = "SellNftTokenPoolT22";
  TensorAmmInstruction2[TensorAmmInstruction2["SellNftTradePoolT22"] = 21] = "SellNftTradePoolT22";
  return TensorAmmInstruction2;
})(TensorAmmInstruction || {});
function identifyTensorAmmInstruction(instruction) {
  const data = "data" in instruction ? instruction.data : instruction;
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([31, 162, 228, 158, 153, 160, 198, 182])
    ),
    0
  )) {
    return 0 /* TammNoop */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([233, 146, 209, 142, 207, 104, 64, 188])
    ),
    0
  )) {
    return 1 /* CreatePool */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([50, 174, 34, 36, 3, 166, 29, 204])
    ),
    0
  )) {
    return 2 /* EditPool */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([140, 189, 209, 23, 239, 62, 239, 11])
    ),
    0
  )) {
    return 3 /* ClosePool */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([108, 212, 233, 53, 132, 83, 63, 219])
    ),
    0
  )) {
    return 4 /* CloseExpiredPool */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([108, 81, 78, 117, 125, 155, 56, 200])
    ),
    0
  )) {
    return 5 /* DepositSol */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([145, 131, 74, 136, 65, 137, 42, 38])
    ),
    0
  )) {
    return 6 /* WithdrawSol */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([93, 226, 132, 166, 141, 9, 48, 101])
    ),
    0
  )) {
    return 7 /* DepositNft */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([142, 181, 191, 149, 82, 175, 216, 100])
    ),
    0
  )) {
    return 8 /* WithdrawNft */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([96, 0, 28, 190, 49, 107, 83, 222])
    ),
    0
  )) {
    return 9 /* BuyNft */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([57, 44, 192, 48, 83, 8, 107, 48])
    ),
    0
  )) {
    return 10 /* SellNftTokenPool */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([131, 82, 125, 77, 13, 157, 36, 90])
    ),
    0
  )) {
    return 11 /* SellNftTradePool */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([73, 21, 4, 64, 161, 214, 248, 77])
    ),
    0
  )) {
    return 12 /* DepositNftCore */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([112, 131, 239, 116, 187, 149, 114, 145])
    ),
    0
  )) {
    return 13 /* WithdrawNftCore */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([163, 102, 58, 107, 184, 4, 169, 121])
    ),
    0
  )) {
    return 14 /* BuyNftCore */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([137, 227, 197, 122, 245, 229, 56, 205])
    ),
    0
  )) {
    return 15 /* SellNftTokenPoolCore */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([37, 205, 141, 53, 86, 245, 45, 78])
    ),
    0
  )) {
    return 16 /* SellNftTradePoolCore */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([208, 34, 6, 147, 95, 218, 49, 160])
    ),
    0
  )) {
    return 17 /* DepositNftT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([112, 55, 80, 231, 181, 190, 92, 12])
    ),
    0
  )) {
    return 18 /* WithdrawNftT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([155, 219, 126, 245, 170, 199, 51, 79])
    ),
    0
  )) {
    return 19 /* BuyNftT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([149, 234, 31, 103, 26, 36, 166, 49])
    ),
    0
  )) {
    return 20 /* SellNftTokenPoolT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([124, 145, 23, 52, 72, 113, 85, 9])
    ),
    0
  )) {
    return 21 /* SellNftTradePoolT22 */;
  }
  throw new Error(
    "The provided instruction could not be identified as a tensorAmm instruction."
  );
}

// src/generated/errors/tensorAmm.ts
var TENSOR_AMM_ERROR__WRONG_WHITELIST = 12e3;
var TENSOR_AMM_ERROR__WRONG_POOL_TYPE = 12001;
var TENSOR_AMM_ERROR__FEES_TOO_HIGH = 12002;
var TENSOR_AMM_ERROR__DELTA_TOO_LARGE = 12003;
var TENSOR_AMM_ERROR__ARITHMETIC_ERROR = 12004;
var TENSOR_AMM_ERROR__PRICE_MISMATCH = 12005;
var TENSOR_AMM_ERROR__EXISTING_NFTS = 12006;
var TENSOR_AMM_ERROR__FEES_NOT_ALLOWED = 12007;
var TENSOR_AMM_ERROR__WRONG_POOL_VERSION = 12008;
var TENSOR_AMM_ERROR__BAD_MINT_PROOF = 12009;
var TENSOR_AMM_ERROR__WRONG_COSIGNER = 12010;
var TENSOR_AMM_ERROR__BAD_SHARED_ESCROW = 12011;
var TENSOR_AMM_ERROR__POOL_ON_SHARED_ESCROW = 12012;
var TENSOR_AMM_ERROR__CANNOT_USE_SHARED_ESCROW = 12013;
var TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_EXCEEDED = 12014;
var TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_TOO_SMALL = 12015;
var TENSOR_AMM_ERROR__STARTING_PRICE_TOO_SMALL = 12016;
var TENSOR_AMM_ERROR__POOL_INSUFFICIENT_RENT = 12017;
var TENSOR_AMM_ERROR__WRONG_RENT_PAYER = 12018;
var TENSOR_AMM_ERROR__EXPIRY_TOO_LARGE = 12019;
var TENSOR_AMM_ERROR__EXPIRED_POOL = 12020;
var TENSOR_AMM_ERROR__POOL_NOT_EXPIRED = 12021;
var TENSOR_AMM_ERROR__INVALID_POOL_AMOUNT = 12022;
var TENSOR_AMM_ERROR__WRONG_MAKER_BROKER = 12023;
var TENSOR_AMM_ERROR__WRONG_OWNER = 12024;
var TENSOR_AMM_ERROR__ESCROW_PROGRAM_NOT_SET = 12025;
var TENSOR_AMM_ERROR__MISSING_MAKER_BROKER = 12026;
var TENSOR_AMM_ERROR__MISSING_COSIGNER = 12027;
var TENSOR_AMM_ERROR__INVALID_EDITION = 12028;
var tensorAmmErrorMessages;
if (process.env.NODE_ENV !== "production") {
  tensorAmmErrorMessages = {
    [TENSOR_AMM_ERROR__ARITHMETIC_ERROR]: `arithmetic error`,
    [TENSOR_AMM_ERROR__BAD_MINT_PROOF]: `bad mint proof account`,
    [TENSOR_AMM_ERROR__BAD_SHARED_ESCROW]: `bad shared escrow account`,
    [TENSOR_AMM_ERROR__CANNOT_USE_SHARED_ESCROW]: `cannot use shared escrow in NFT pools`,
    [TENSOR_AMM_ERROR__DELTA_TOO_LARGE]: `delta too large`,
    [TENSOR_AMM_ERROR__ESCROW_PROGRAM_NOT_SET]: `Escrow program not set`,
    [TENSOR_AMM_ERROR__EXISTING_NFTS]: `cannot close pool with nfts in escrow -- withdraw all before closing`,
    [TENSOR_AMM_ERROR__EXPIRED_POOL]: `Expired Pool`,
    [TENSOR_AMM_ERROR__EXPIRY_TOO_LARGE]: `Expiry too large`,
    [TENSOR_AMM_ERROR__FEES_NOT_ALLOWED]: `fees not allowed for non-trade pools`,
    [TENSOR_AMM_ERROR__FEES_TOO_HIGH]: `fees entered above allowed threshold`,
    [TENSOR_AMM_ERROR__INVALID_EDITION]: `Invalid edition`,
    [TENSOR_AMM_ERROR__INVALID_POOL_AMOUNT]: `Invalid pool amount`,
    [TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_EXCEEDED]: `max taker sell count exceeded, pool cannot buy anymore NFTs`,
    [TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_TOO_SMALL]: `max taker sell count is too small`,
    [TENSOR_AMM_ERROR__MISSING_COSIGNER]: `Missing cosigner account`,
    [TENSOR_AMM_ERROR__MISSING_MAKER_BROKER]: `Missing maker broker account`,
    [TENSOR_AMM_ERROR__POOL_INSUFFICIENT_RENT]: `Pool must keep minimum rent balance`,
    [TENSOR_AMM_ERROR__POOL_NOT_EXPIRED]: `Pool not expired`,
    [TENSOR_AMM_ERROR__POOL_ON_SHARED_ESCROW]: `expected a non-shared escrow pool to be passed in`,
    [TENSOR_AMM_ERROR__PRICE_MISMATCH]: `specified price not within current price`,
    [TENSOR_AMM_ERROR__STARTING_PRICE_TOO_SMALL]: `starting price can't be smaller than 1 lamport`,
    [TENSOR_AMM_ERROR__WRONG_COSIGNER]: `wrong cosigner`,
    [TENSOR_AMM_ERROR__WRONG_MAKER_BROKER]: `Wrong maker broker account`,
    [TENSOR_AMM_ERROR__WRONG_OWNER]: `Wrong owner`,
    [TENSOR_AMM_ERROR__WRONG_POOL_TYPE]: `operation not permitted on this pool type`,
    [TENSOR_AMM_ERROR__WRONG_POOL_VERSION]: `wrong pool version provided`,
    [TENSOR_AMM_ERROR__WRONG_RENT_PAYER]: `Wrong rent payer`,
    [TENSOR_AMM_ERROR__WRONG_WHITELIST]: `wrong whitelist`
  };
}
function getTensorAmmErrorMessage(code) {
  if (process.env.NODE_ENV !== "production") {
    return tensorAmmErrorMessages[code];
  }
  return "Error message not available in production bundles.";
}
function isTensorAmmError(error, transactionMessage, code) {
  return web3_js.isProgramError(
    error,
    transactionMessage,
    TENSOR_AMM_PROGRAM_ADDRESS,
    code
  );
}

// src/generated/instructions/buyNft.ts
init_env_shim();
var BUY_NFT_DISCRIMINATOR = new Uint8Array([
  96,
  0,
  28,
  190,
  49,
  107,
  83,
  222
]);
function getBuyNftDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(BUY_NFT_DISCRIMINATOR);
}
function getBuyNftInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: BUY_NFT_DISCRIMINATOR,
      authorizationData: value.authorizationData ?? web3_js.none(),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none()
    })
  );
}
function getBuyNftInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())]
  ]);
}
function getBuyNftInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyNftInstructionDataEncoder(),
    getBuyNftInstructionDataDecoder()
  );
}
async function getBuyNftInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEdition(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.takerTa.value) {
    accounts.takerTa = {
      ...accounts.takerTa,
      ...await resolveTakerAta(resolverScope)
    };
  }
  if (!accounts.userTokenRecord.value) {
    accounts.userTokenRecord = {
      ...accounts.userTokenRecord,
      ...await resolveUserTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvers.resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyNftInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyNftInstruction(instruction) {
  if (instruction.accounts.length < 29) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      userTokenRecord: getNextOptionalAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      nftReceipt: getNextAccount(),
      takerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getBuyNftInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/buyNftCore.ts
init_env_shim();
var BUY_NFT_CORE_DISCRIMINATOR = new Uint8Array([
  163,
  102,
  58,
  107,
  184,
  4,
  169,
  121
]);
function getBuyNftCoreDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    BUY_NFT_CORE_DISCRIMINATOR
  );
}
function getBuyNftCoreInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: BUY_NFT_CORE_DISCRIMINATOR })
  );
}
function getBuyNftCoreInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getBuyNftCoreInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyNftCoreInstructionDataEncoder(),
    getBuyNftCoreInstructionDataDecoder()
  );
}
async function getBuyNftCoreInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findAssetDepositReceiptPda({
      asset: expectAddress(accounts.asset.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyNftCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyNftCoreInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyNftCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyNftCoreInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      mplCoreProgram: getNextAccount(),
      nftReceipt: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getBuyNftCoreInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/buyNftT22.ts
init_env_shim();
var BUY_NFT_T22_DISCRIMINATOR = new Uint8Array([
  155,
  219,
  126,
  245,
  170,
  199,
  51,
  79
]);
function getBuyNftT22DiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(BUY_NFT_T22_DISCRIMINATOR);
}
function getBuyNftT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: BUY_NFT_T22_DISCRIMINATOR })
  );
}
function getBuyNftT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getBuyNftT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyNftT22InstructionDataEncoder(),
    getBuyNftT22InstructionDataDecoder()
  );
}
async function getBuyNftT22InstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.takerTa.value) {
    accounts.takerTa = {
      ...accounts.takerTa,
      ...await resolveTakerAta(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address4) => ({
      address: address4,
      role: web3_js.AccountRole.WRITABLE
    })),
    ...args.transferHookAccounts.map((address4) => ({
      address: address4,
      role: web3_js.AccountRole.READONLY
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyNftT22Instruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address4) => ({
      address: address4,
      role: web3_js.AccountRole.WRITABLE
    })),
    ...args.transferHookAccounts.map((address4) => ({
      address: address4,
      role: web3_js.AccountRole.READONLY
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyNftT22Instruction(instruction) {
  if (instruction.accounts.length < 21) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      mint: getNextAccount(),
      nftReceipt: getNextAccount(),
      takerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getBuyNftT22InstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/closeExpiredPool.ts
init_env_shim();
var CLOSE_EXPIRED_POOL_DISCRIMINATOR = new Uint8Array([
  108,
  212,
  233,
  53,
  132,
  83,
  63,
  219
]);
function getCloseExpiredPoolDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    CLOSE_EXPIRED_POOL_DISCRIMINATOR
  );
}
function getCloseExpiredPoolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({ ...value, discriminator: CLOSE_EXPIRED_POOL_DISCRIMINATOR })
  );
}
function getCloseExpiredPoolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getCloseExpiredPoolInstructionDataCodec() {
  return web3_js.combineCodec(
    getCloseExpiredPoolInstructionDataEncoder(),
    getCloseExpiredPoolInstructionDataDecoder()
  );
}
function getCloseExpiredPoolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCloseExpiredPoolInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCloseExpiredPoolInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      rentPayer: getNextAccount(),
      owner: getNextAccount(),
      pool: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getCloseExpiredPoolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/closePool.ts
init_env_shim();
var CLOSE_POOL_DISCRIMINATOR = new Uint8Array([
  140,
  189,
  209,
  23,
  239,
  62,
  239,
  11
]);
function getClosePoolDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(CLOSE_POOL_DISCRIMINATOR);
}
function getClosePoolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({ ...value, discriminator: CLOSE_POOL_DISCRIMINATOR })
  );
}
function getClosePoolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getClosePoolInstructionDataCodec() {
  return web3_js.combineCodec(
    getClosePoolInstructionDataEncoder(),
    getClosePoolInstructionDataDecoder()
  );
}
function getClosePoolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectTransactionSigner(
      accounts.owner.value
    ).address;
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getClosePoolInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseClosePoolInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      rentPayer: getNextAccount(),
      owner: getNextAccount(),
      pool: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getClosePoolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/createPool.ts
init_env_shim();
var CREATE_POOL_DISCRIMINATOR = new Uint8Array([
  233,
  146,
  209,
  142,
  207,
  104,
  64,
  188
]);
function getCreatePoolDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(CREATE_POOL_DISCRIMINATOR);
}
function getCreatePoolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["poolId", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["config", getPoolConfigEncoder()],
      ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["cosigner", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["makerBroker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["maxTakerSellCount", web3_js.getOptionEncoder(web3_js.getU32Encoder())],
      ["expireInSec", web3_js.getOptionEncoder(web3_js.getU64Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: CREATE_POOL_DISCRIMINATOR,
      currency: value.currency ?? web3_js.none(),
      cosigner: value.cosigner ?? web3_js.none(),
      makerBroker: value.makerBroker ?? web3_js.none(),
      maxTakerSellCount: value.maxTakerSellCount ?? web3_js.none(),
      expireInSec: value.expireInSec ?? web3_js.none()
    })
  );
}
function getCreatePoolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["poolId", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["config", getPoolConfigDecoder()],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["cosigner", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["makerBroker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["maxTakerSellCount", web3_js.getOptionDecoder(web3_js.getU32Decoder())],
    ["expireInSec", web3_js.getOptionDecoder(web3_js.getU64Decoder())]
  ]);
}
function getCreatePoolInstructionDataCodec() {
  return web3_js.combineCodec(
    getCreatePoolInstructionDataEncoder(),
    getCreatePoolInstructionDataDecoder()
  );
}
async function getCreatePoolInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!args.poolId) {
    args.poolId = resolvePoolIdOnCreate();
  }
  if (!accounts.pool.value) {
    accounts.pool.value = await findPoolPda({
      owner: expectAddress(accounts.owner.value),
      poolId: expectSome(args.poolId)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreatePoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getCreatePoolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!args.poolId) {
    args.poolId = resolvePoolIdOnCreate();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreatePoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreatePoolInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      rentPayer: getNextAccount(),
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      systemProgram: getNextAccount()
    },
    data: getCreatePoolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/depositNft.ts
init_env_shim();
var DEPOSIT_NFT_DISCRIMINATOR = new Uint8Array([
  93,
  226,
  132,
  166,
  141,
  9,
  48,
  101
]);
function getDepositNftDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(DEPOSIT_NFT_DISCRIMINATOR);
}
function getDepositNftInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: DEPOSIT_NFT_DISCRIMINATOR,
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getDepositNftInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getDepositNftInstructionDataCodec() {
  return web3_js.combineCodec(
    getDepositNftInstructionDataEncoder(),
    getDepositNftInstructionDataDecoder()
  );
}
async function getDepositNftInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEdition(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.userTokenRecord.value) {
    accounts.userTokenRecord = {
      ...accounts.userTokenRecord,
      ...await resolveUserTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvers.resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getDepositNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getDepositNftInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getDepositNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseDepositNftInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      userTokenRecord: getNextOptionalAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      nftReceipt: getNextAccount(),
      ownerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getDepositNftInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/depositNftCore.ts
init_env_shim();
var DEPOSIT_NFT_CORE_DISCRIMINATOR = new Uint8Array([
  73,
  21,
  4,
  64,
  161,
  214,
  248,
  77
]);
function getDepositNftCoreDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    DEPOSIT_NFT_CORE_DISCRIMINATOR
  );
}
function getDepositNftCoreInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({ ...value, discriminator: DEPOSIT_NFT_CORE_DISCRIMINATOR })
  );
}
function getDepositNftCoreInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getDepositNftCoreInstructionDataCodec() {
  return web3_js.combineCodec(
    getDepositNftCoreInstructionDataEncoder(),
    getDepositNftCoreInstructionDataDecoder()
  );
}
async function getDepositNftCoreInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findAssetDepositReceiptPda({
      asset: expectAddress(accounts.asset.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getDepositNftCoreInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getDepositNftCoreInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getDepositNftCoreInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDepositNftCoreInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      mplCoreProgram: getNextAccount(),
      nftReceipt: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getDepositNftCoreInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/depositNftT22.ts
init_env_shim();
var DEPOSIT_NFT_T22_DISCRIMINATOR = new Uint8Array([
  208,
  34,
  6,
  147,
  95,
  218,
  49,
  160
]);
function getDepositNftT22DiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    DEPOSIT_NFT_T22_DISCRIMINATOR
  );
}
function getDepositNftT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({ ...value, discriminator: DEPOSIT_NFT_T22_DISCRIMINATOR })
  );
}
function getDepositNftT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getDepositNftT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getDepositNftT22InstructionDataEncoder(),
    getDepositNftT22InstructionDataDecoder()
  );
}
async function getDepositNftT22InstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = args.transferHookAccounts.map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.READONLY })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getDepositNftT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function getDepositNftT22Instruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = args.transferHookAccounts.map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.READONLY })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getDepositNftT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDepositNftT22Instruction(instruction) {
  if (instruction.accounts.length < 11) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      mint: getNextAccount(),
      nftReceipt: getNextAccount(),
      ownerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getDepositNftT22InstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/depositSol.ts
init_env_shim();
var DEPOSIT_SOL_DISCRIMINATOR = new Uint8Array([
  108,
  81,
  78,
  117,
  125,
  155,
  56,
  200
]);
function getDepositSolDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(DEPOSIT_SOL_DISCRIMINATOR);
}
function getDepositSolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["lamports", web3_js.getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: DEPOSIT_SOL_DISCRIMINATOR })
  );
}
function getDepositSolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["lamports", web3_js.getU64Decoder()]
  ]);
}
function getDepositSolInstructionDataCodec() {
  return web3_js.combineCodec(
    getDepositSolInstructionDataEncoder(),
    getDepositSolInstructionDataDecoder()
  );
}
function getDepositSolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getDepositSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseDepositSolInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getDepositSolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/editPool.ts
init_env_shim();
var EDIT_POOL_DISCRIMINATOR = new Uint8Array([
  50,
  174,
  34,
  36,
  3,
  166,
  29,
  204
]);
function getEditPoolDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(EDIT_POOL_DISCRIMINATOR);
}
function getEditPoolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["newConfig", web3_js.getOptionEncoder(getEditPoolConfigEncoder())],
      ["cosigner", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["makerBroker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["expireInSec", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
      ["maxTakerSellCount", web3_js.getOptionEncoder(web3_js.getU32Encoder())],
      ["resetPriceOffset", web3_js.getBooleanEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: EDIT_POOL_DISCRIMINATOR,
      cosigner: value.cosigner ?? web3_js.none(),
      makerBroker: value.makerBroker ?? web3_js.none(),
      expireInSec: value.expireInSec ?? web3_js.none(),
      maxTakerSellCount: value.maxTakerSellCount ?? web3_js.none()
    })
  );
}
function getEditPoolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["newConfig", web3_js.getOptionDecoder(getEditPoolConfigDecoder())],
    ["cosigner", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["makerBroker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["expireInSec", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["maxTakerSellCount", web3_js.getOptionDecoder(web3_js.getU32Decoder())],
    ["resetPriceOffset", web3_js.getBooleanDecoder()]
  ]);
}
function getEditPoolInstructionDataCodec() {
  return web3_js.combineCodec(
    getEditPoolInstructionDataEncoder(),
    getEditPoolInstructionDataDecoder()
  );
}
function getEditPoolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    pool: { value: input.pool ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getEditPoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseEditPoolInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getEditPoolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/sellNftTokenPool.ts
init_env_shim();
var SELL_NFT_TOKEN_POOL_DISCRIMINATOR = new Uint8Array([
  57,
  44,
  192,
  48,
  83,
  8,
  107,
  48
]);
function getSellNftTokenPoolDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    SELL_NFT_TOKEN_POOL_DISCRIMINATOR
  );
}
function getSellNftTokenPoolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minPrice", web3_js.getU64Encoder()],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: SELL_NFT_TOKEN_POOL_DISCRIMINATOR,
      authorizationData: value.authorizationData ?? web3_js.none(),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none()
    })
  );
}
function getSellNftTokenPoolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minPrice", web3_js.getU64Decoder()],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())]
  ]);
}
function getSellNftTokenPoolInstructionDataCodec() {
  return web3_js.combineCodec(
    getSellNftTokenPoolInstructionDataEncoder(),
    getSellNftTokenPoolInstructionDataDecoder()
  );
}
async function getSellNftTokenPoolInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEdition(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.takerTa.value) {
    accounts.takerTa = {
      ...accounts.takerTa,
      ...await resolveTakerAta(resolverScope)
    };
  }
  if (!accounts.userTokenRecord.value) {
    accounts.userTokenRecord = {
      ...accounts.userTokenRecord,
      ...await resolveUserTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvers.resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.ownerTokenRecord.value) {
    accounts.ownerTokenRecord = {
      ...accounts.ownerTokenRecord,
      ...await resolvers.resolveOwnerTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTokenPoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellNftTokenPoolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTokenPoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellNftTokenPoolInstruction(instruction) {
  if (instruction.accounts.length < 30) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      userTokenRecord: getNextOptionalAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      takerTa: getNextAccount(),
      ownerTa: getNextAccount(),
      poolTa: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getSellNftTokenPoolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/sellNftTokenPoolCore.ts
init_env_shim();
var SELL_NFT_TOKEN_POOL_CORE_DISCRIMINATOR = new Uint8Array([
  137,
  227,
  197,
  122,
  245,
  229,
  56,
  205
]);
function getSellNftTokenPoolCoreDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    SELL_NFT_TOKEN_POOL_CORE_DISCRIMINATOR
  );
}
function getSellNftTokenPoolCoreInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minPrice", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: SELL_NFT_TOKEN_POOL_CORE_DISCRIMINATOR
    })
  );
}
function getSellNftTokenPoolCoreInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minPrice", web3_js.getU64Decoder()]
  ]);
}
function getSellNftTokenPoolCoreInstructionDataCodec() {
  return web3_js.combineCodec(
    getSellNftTokenPoolCoreInstructionDataEncoder(),
    getSellNftTokenPoolCoreInstructionDataDecoder()
  );
}
async function getSellNftTokenPoolCoreInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTokenPoolCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellNftTokenPoolCoreInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTokenPoolCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellNftTokenPoolCoreInstruction(instruction) {
  if (instruction.accounts.length < 17) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      mplCoreProgram: getNextAccount()
    },
    data: getSellNftTokenPoolCoreInstructionDataDecoder().decode(
      instruction.data
    )
  };
}

// src/generated/instructions/sellNftTokenPoolT22.ts
init_env_shim();
var SELL_NFT_TOKEN_POOL_T22_DISCRIMINATOR = new Uint8Array([
  149,
  234,
  31,
  103,
  26,
  36,
  166,
  49
]);
function getSellNftTokenPoolT22DiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    SELL_NFT_TOKEN_POOL_T22_DISCRIMINATOR
  );
}
function getSellNftTokenPoolT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minPrice", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: SELL_NFT_TOKEN_POOL_T22_DISCRIMINATOR
    })
  );
}
function getSellNftTokenPoolT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minPrice", web3_js.getU64Decoder()]
  ]);
}
function getSellNftTokenPoolT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getSellNftTokenPoolT22InstructionDataEncoder(),
    getSellNftTokenPoolT22InstructionDataDecoder()
  );
}
async function getSellNftTokenPoolT22InstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.takerTa.value) {
    accounts.takerTa = {
      ...accounts.takerTa,
      ...await resolveTakerAta(resolverScope)
    };
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address4) => ({
      address: address4,
      role: web3_js.AccountRole.WRITABLE
    })),
    ...args.transferHookAccounts.map((address4) => ({
      address: address4,
      role: web3_js.AccountRole.READONLY
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTokenPoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellNftTokenPoolT22Instruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address4) => ({
      address: address4,
      role: web3_js.AccountRole.WRITABLE
    })),
    ...args.transferHookAccounts.map((address4) => ({
      address: address4,
      role: web3_js.AccountRole.READONLY
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTokenPoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellNftTokenPoolT22Instruction(instruction) {
  if (instruction.accounts.length < 20) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      mint: getNextAccount(),
      takerTa: getNextAccount(),
      ownerTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getSellNftTokenPoolT22InstructionDataDecoder().decode(
      instruction.data
    )
  };
}

// src/generated/instructions/sellNftTradePool.ts
init_env_shim();
var SELL_NFT_TRADE_POOL_DISCRIMINATOR = new Uint8Array([
  131,
  82,
  125,
  77,
  13,
  157,
  36,
  90
]);
function getSellNftTradePoolDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    SELL_NFT_TRADE_POOL_DISCRIMINATOR
  );
}
function getSellNftTradePoolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minPrice", web3_js.getU64Encoder()],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: SELL_NFT_TRADE_POOL_DISCRIMINATOR,
      authorizationData: value.authorizationData ?? web3_js.none(),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none()
    })
  );
}
function getSellNftTradePoolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minPrice", web3_js.getU64Decoder()],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())]
  ]);
}
function getSellNftTradePoolInstructionDataCodec() {
  return web3_js.combineCodec(
    getSellNftTradePoolInstructionDataEncoder(),
    getSellNftTradePoolInstructionDataDecoder()
  );
}
async function getSellNftTradePoolInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEdition(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.takerTa.value) {
    accounts.takerTa = {
      ...accounts.takerTa,
      ...await resolveTakerAta(resolverScope)
    };
  }
  if (!accounts.userTokenRecord.value) {
    accounts.userTokenRecord = {
      ...accounts.userTokenRecord,
      ...await resolveUserTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvers.resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTradePoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellNftTradePoolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTradePoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellNftTradePoolInstruction(instruction) {
  if (instruction.accounts.length < 29) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      userTokenRecord: getNextOptionalAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      nftReceipt: getNextAccount(),
      takerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getSellNftTradePoolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/sellNftTradePoolCore.ts
init_env_shim();
var SELL_NFT_TRADE_POOL_CORE_DISCRIMINATOR = new Uint8Array([
  37,
  205,
  141,
  53,
  86,
  245,
  45,
  78
]);
function getSellNftTradePoolCoreDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    SELL_NFT_TRADE_POOL_CORE_DISCRIMINATOR
  );
}
function getSellNftTradePoolCoreInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minPrice", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: SELL_NFT_TRADE_POOL_CORE_DISCRIMINATOR
    })
  );
}
function getSellNftTradePoolCoreInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minPrice", web3_js.getU64Decoder()]
  ]);
}
function getSellNftTradePoolCoreInstructionDataCodec() {
  return web3_js.combineCodec(
    getSellNftTradePoolCoreInstructionDataEncoder(),
    getSellNftTradePoolCoreInstructionDataDecoder()
  );
}
async function getSellNftTradePoolCoreInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findAssetDepositReceiptPda({
      asset: expectAddress(accounts.asset.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTradePoolCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellNftTradePoolCoreInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTradePoolCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellNftTradePoolCoreInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      mplCoreProgram: getNextAccount(),
      nftReceipt: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getSellNftTradePoolCoreInstructionDataDecoder().decode(
      instruction.data
    )
  };
}

// src/generated/instructions/sellNftTradePoolT22.ts
init_env_shim();
var SELL_NFT_TRADE_POOL_T22_DISCRIMINATOR = new Uint8Array([
  124,
  145,
  23,
  52,
  72,
  113,
  85,
  9
]);
function getSellNftTradePoolT22DiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    SELL_NFT_TRADE_POOL_T22_DISCRIMINATOR
  );
}
function getSellNftTradePoolT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minPrice", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: SELL_NFT_TRADE_POOL_T22_DISCRIMINATOR
    })
  );
}
function getSellNftTradePoolT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minPrice", web3_js.getU64Decoder()]
  ]);
}
function getSellNftTradePoolT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getSellNftTradePoolT22InstructionDataEncoder(),
    getSellNftTradePoolT22InstructionDataDecoder()
  );
}
async function getSellNftTradePoolT22InstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.takerTa.value) {
    accounts.takerTa = {
      ...accounts.takerTa,
      ...await resolveTakerAta(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address4) => ({
      address: address4,
      role: web3_js.AccountRole.WRITABLE
    })),
    ...args.transferHookAccounts.map((address4) => ({
      address: address4,
      role: web3_js.AccountRole.READONLY
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTradePoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellNftTradePoolT22Instruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolvers.resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address4) => ({
      address: address4,
      role: web3_js.AccountRole.WRITABLE
    })),
    ...args.transferHookAccounts.map((address4) => ({
      address: address4,
      role: web3_js.AccountRole.READONLY
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTradePoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellNftTradePoolT22Instruction(instruction) {
  if (instruction.accounts.length < 21) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      mint: getNextAccount(),
      nftReceipt: getNextAccount(),
      takerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getSellNftTradePoolT22InstructionDataDecoder().decode(
      instruction.data
    )
  };
}

// src/generated/instructions/tammNoop.ts
init_env_shim();
var TAMM_NOOP_DISCRIMINATOR = new Uint8Array([
  31,
  162,
  228,
  158,
  153,
  160,
  198,
  182
]);
function getTammNoopDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(TAMM_NOOP_DISCRIMINATOR);
}
function getTammNoopInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["event", getTAmmEventEncoder()]
    ]),
    (value) => ({ ...value, discriminator: TAMM_NOOP_DISCRIMINATOR })
  );
}
function getTammNoopInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["event", getTAmmEventDecoder()]
  ]);
}
function getTammNoopInstructionDataCodec() {
  return web3_js.combineCodec(
    getTammNoopInstructionDataEncoder(),
    getTammNoopInstructionDataDecoder()
  );
}
function getTammNoopInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    pool: { value: input.pool ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [getAccountMeta(accounts.pool)],
    programAddress,
    data: getTammNoopInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammNoopInstruction(instruction) {
  if (instruction.accounts.length < 1) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      pool: getNextAccount()
    },
    data: getTammNoopInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/withdrawNft.ts
init_env_shim();
var WITHDRAW_NFT_DISCRIMINATOR = new Uint8Array([
  142,
  181,
  191,
  149,
  82,
  175,
  216,
  100
]);
function getWithdrawNftDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    WITHDRAW_NFT_DISCRIMINATOR
  );
}
function getWithdrawNftInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: WITHDRAW_NFT_DISCRIMINATOR,
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getWithdrawNftInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getWithdrawNftInstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawNftInstructionDataEncoder(),
    getWithdrawNftInstructionDataDecoder()
  );
}
async function getWithdrawNftInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEdition(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.userTokenRecord.value) {
    accounts.userTokenRecord = {
      ...accounts.userTokenRecord,
      ...await resolveUserTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvers.resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getWithdrawNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawNftInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getWithdrawNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawNftInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      userTokenRecord: getNextOptionalAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      nftReceipt: getNextAccount(),
      ownerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getWithdrawNftInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/withdrawNftCore.ts
init_env_shim();
var WITHDRAW_NFT_CORE_DISCRIMINATOR = new Uint8Array([
  112,
  131,
  239,
  116,
  187,
  149,
  114,
  145
]);
function getWithdrawNftCoreDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    WITHDRAW_NFT_CORE_DISCRIMINATOR
  );
}
function getWithdrawNftCoreInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({ ...value, discriminator: WITHDRAW_NFT_CORE_DISCRIMINATOR })
  );
}
function getWithdrawNftCoreInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getWithdrawNftCoreInstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawNftCoreInstructionDataEncoder(),
    getWithdrawNftCoreInstructionDataDecoder()
  );
}
async function getWithdrawNftCoreInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findAssetDepositReceiptPda({
      asset: expectAddress(accounts.asset.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt)
    ],
    programAddress,
    data: getWithdrawNftCoreInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getWithdrawNftCoreInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt)
    ],
    programAddress,
    data: getWithdrawNftCoreInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseWithdrawNftCoreInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      mplCoreProgram: getNextAccount(),
      nftReceipt: getNextAccount()
    },
    data: getWithdrawNftCoreInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/withdrawNftT22.ts
init_env_shim();
var WITHDRAW_NFT_T22_DISCRIMINATOR = new Uint8Array([
  112,
  55,
  80,
  231,
  181,
  190,
  92,
  12
]);
function getWithdrawNftT22DiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    WITHDRAW_NFT_T22_DISCRIMINATOR
  );
}
function getWithdrawNftT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({ ...value, discriminator: WITHDRAW_NFT_T22_DISCRIMINATOR })
  );
}
function getWithdrawNftT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getWithdrawNftT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawNftT22InstructionDataEncoder(),
    getWithdrawNftT22InstructionDataDecoder()
  );
}
async function getWithdrawNftT22InstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = args.transferHookAccounts.map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.READONLY })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getWithdrawNftT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function getWithdrawNftT22Instruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = args.transferHookAccounts.map(
    (address4) => ({ address: address4, role: web3_js.AccountRole.READONLY })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getWithdrawNftT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseWithdrawNftT22Instruction(instruction) {
  if (instruction.accounts.length < 11) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      mint: getNextAccount(),
      nftReceipt: getNextAccount(),
      ownerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getWithdrawNftT22InstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/withdrawSol.ts
init_env_shim();
var WITHDRAW_SOL_DISCRIMINATOR = new Uint8Array([
  145,
  131,
  74,
  136,
  65,
  137,
  42,
  38
]);
function getWithdrawSolDiscriminatorBytes() {
  return web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
    WITHDRAW_SOL_DISCRIMINATOR
  );
}
function getWithdrawSolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["lamports", web3_js.getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: WITHDRAW_SOL_DISCRIMINATOR })
  );
}
function getWithdrawSolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["lamports", web3_js.getU64Decoder()]
  ]);
}
function getWithdrawSolInstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawSolInstructionDataEncoder(),
    getWithdrawSolInstructionDataDecoder()
  );
}
function getWithdrawSolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getWithdrawSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawSolInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getWithdrawSolInstructionDataDecoder().decode(instruction.data)
  };
}

exports.ASSET_DEPOSIT_RECEIPT_DISCRIMINATOR = ASSET_DEPOSIT_RECEIPT_DISCRIMINATOR;
exports.BUY_NFT_CORE_DISCRIMINATOR = BUY_NFT_CORE_DISCRIMINATOR;
exports.BUY_NFT_DISCRIMINATOR = BUY_NFT_DISCRIMINATOR;
exports.BUY_NFT_T22_DISCRIMINATOR = BUY_NFT_T22_DISCRIMINATOR;
exports.CLOSE_EXPIRED_POOL_DISCRIMINATOR = CLOSE_EXPIRED_POOL_DISCRIMINATOR;
exports.CLOSE_POOL_DISCRIMINATOR = CLOSE_POOL_DISCRIMINATOR;
exports.CREATE_POOL_DISCRIMINATOR = CREATE_POOL_DISCRIMINATOR;
exports.CurveType = CurveType;
exports.DEFAULT_ADDRESS = DEFAULT_ADDRESS;
exports.DEPOSIT_NFT_CORE_DISCRIMINATOR = DEPOSIT_NFT_CORE_DISCRIMINATOR;
exports.DEPOSIT_NFT_DISCRIMINATOR = DEPOSIT_NFT_DISCRIMINATOR;
exports.DEPOSIT_NFT_T22_DISCRIMINATOR = DEPOSIT_NFT_T22_DISCRIMINATOR;
exports.DEPOSIT_SOL_DISCRIMINATOR = DEPOSIT_SOL_DISCRIMINATOR;
exports.Direction = Direction;
exports.EDIT_POOL_DISCRIMINATOR = EDIT_POOL_DISCRIMINATOR;
exports.NFT_DEPOSIT_RECEIPT_DISCRIMINATOR = NFT_DEPOSIT_RECEIPT_DISCRIMINATOR;
exports.POOL_DISCRIMINATOR = POOL_DISCRIMINATOR;
exports.PoolType = PoolType;
exports.SELL_NFT_TOKEN_POOL_CORE_DISCRIMINATOR = SELL_NFT_TOKEN_POOL_CORE_DISCRIMINATOR;
exports.SELL_NFT_TOKEN_POOL_DISCRIMINATOR = SELL_NFT_TOKEN_POOL_DISCRIMINATOR;
exports.SELL_NFT_TOKEN_POOL_T22_DISCRIMINATOR = SELL_NFT_TOKEN_POOL_T22_DISCRIMINATOR;
exports.SELL_NFT_TRADE_POOL_CORE_DISCRIMINATOR = SELL_NFT_TRADE_POOL_CORE_DISCRIMINATOR;
exports.SELL_NFT_TRADE_POOL_DISCRIMINATOR = SELL_NFT_TRADE_POOL_DISCRIMINATOR;
exports.SELL_NFT_TRADE_POOL_T22_DISCRIMINATOR = SELL_NFT_TRADE_POOL_T22_DISCRIMINATOR;
exports.TAMM_NOOP_DISCRIMINATOR = TAMM_NOOP_DISCRIMINATOR;
exports.TENSOR_AMM_ERROR__ARITHMETIC_ERROR = TENSOR_AMM_ERROR__ARITHMETIC_ERROR;
exports.TENSOR_AMM_ERROR__BAD_MINT_PROOF = TENSOR_AMM_ERROR__BAD_MINT_PROOF;
exports.TENSOR_AMM_ERROR__BAD_SHARED_ESCROW = TENSOR_AMM_ERROR__BAD_SHARED_ESCROW;
exports.TENSOR_AMM_ERROR__CANNOT_USE_SHARED_ESCROW = TENSOR_AMM_ERROR__CANNOT_USE_SHARED_ESCROW;
exports.TENSOR_AMM_ERROR__DELTA_TOO_LARGE = TENSOR_AMM_ERROR__DELTA_TOO_LARGE;
exports.TENSOR_AMM_ERROR__ESCROW_PROGRAM_NOT_SET = TENSOR_AMM_ERROR__ESCROW_PROGRAM_NOT_SET;
exports.TENSOR_AMM_ERROR__EXISTING_NFTS = TENSOR_AMM_ERROR__EXISTING_NFTS;
exports.TENSOR_AMM_ERROR__EXPIRED_POOL = TENSOR_AMM_ERROR__EXPIRED_POOL;
exports.TENSOR_AMM_ERROR__EXPIRY_TOO_LARGE = TENSOR_AMM_ERROR__EXPIRY_TOO_LARGE;
exports.TENSOR_AMM_ERROR__FEES_NOT_ALLOWED = TENSOR_AMM_ERROR__FEES_NOT_ALLOWED;
exports.TENSOR_AMM_ERROR__FEES_TOO_HIGH = TENSOR_AMM_ERROR__FEES_TOO_HIGH;
exports.TENSOR_AMM_ERROR__INVALID_EDITION = TENSOR_AMM_ERROR__INVALID_EDITION;
exports.TENSOR_AMM_ERROR__INVALID_POOL_AMOUNT = TENSOR_AMM_ERROR__INVALID_POOL_AMOUNT;
exports.TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_EXCEEDED = TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_EXCEEDED;
exports.TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_TOO_SMALL = TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_TOO_SMALL;
exports.TENSOR_AMM_ERROR__MISSING_COSIGNER = TENSOR_AMM_ERROR__MISSING_COSIGNER;
exports.TENSOR_AMM_ERROR__MISSING_MAKER_BROKER = TENSOR_AMM_ERROR__MISSING_MAKER_BROKER;
exports.TENSOR_AMM_ERROR__POOL_INSUFFICIENT_RENT = TENSOR_AMM_ERROR__POOL_INSUFFICIENT_RENT;
exports.TENSOR_AMM_ERROR__POOL_NOT_EXPIRED = TENSOR_AMM_ERROR__POOL_NOT_EXPIRED;
exports.TENSOR_AMM_ERROR__POOL_ON_SHARED_ESCROW = TENSOR_AMM_ERROR__POOL_ON_SHARED_ESCROW;
exports.TENSOR_AMM_ERROR__PRICE_MISMATCH = TENSOR_AMM_ERROR__PRICE_MISMATCH;
exports.TENSOR_AMM_ERROR__STARTING_PRICE_TOO_SMALL = TENSOR_AMM_ERROR__STARTING_PRICE_TOO_SMALL;
exports.TENSOR_AMM_ERROR__WRONG_COSIGNER = TENSOR_AMM_ERROR__WRONG_COSIGNER;
exports.TENSOR_AMM_ERROR__WRONG_MAKER_BROKER = TENSOR_AMM_ERROR__WRONG_MAKER_BROKER;
exports.TENSOR_AMM_ERROR__WRONG_OWNER = TENSOR_AMM_ERROR__WRONG_OWNER;
exports.TENSOR_AMM_ERROR__WRONG_POOL_TYPE = TENSOR_AMM_ERROR__WRONG_POOL_TYPE;
exports.TENSOR_AMM_ERROR__WRONG_POOL_VERSION = TENSOR_AMM_ERROR__WRONG_POOL_VERSION;
exports.TENSOR_AMM_ERROR__WRONG_RENT_PAYER = TENSOR_AMM_ERROR__WRONG_RENT_PAYER;
exports.TENSOR_AMM_ERROR__WRONG_WHITELIST = TENSOR_AMM_ERROR__WRONG_WHITELIST;
exports.TENSOR_AMM_PROGRAM_ADDRESS = TENSOR_AMM_PROGRAM_ADDRESS;
exports.TakerSide = TakerSide;
exports.TensorAmmAccount = TensorAmmAccount;
exports.TensorAmmInstruction = TensorAmmInstruction;
exports.TransferDirection = TransferDirection;
exports.WITHDRAW_NFT_CORE_DISCRIMINATOR = WITHDRAW_NFT_CORE_DISCRIMINATOR;
exports.WITHDRAW_NFT_DISCRIMINATOR = WITHDRAW_NFT_DISCRIMINATOR;
exports.WITHDRAW_NFT_T22_DISCRIMINATOR = WITHDRAW_NFT_T22_DISCRIMINATOR;
exports.WITHDRAW_SOL_DISCRIMINATOR = WITHDRAW_SOL_DISCRIMINATOR;
exports.calculateAmountForQuantity = calculateAmountForQuantity;
exports.calculatePrice = calculatePrice;
exports.decodeAssetDepositReceipt = decodeAssetDepositReceipt;
exports.decodeNftDepositReceipt = decodeNftDepositReceipt;
exports.decodePool = decodePool;
exports.fetchAllAssetDepositReceipt = fetchAllAssetDepositReceipt;
exports.fetchAllMaybeAssetDepositReceipt = fetchAllMaybeAssetDepositReceipt;
exports.fetchAllMaybeNftDepositReceipt = fetchAllMaybeNftDepositReceipt;
exports.fetchAllMaybePool = fetchAllMaybePool;
exports.fetchAllNftDepositReceipt = fetchAllNftDepositReceipt;
exports.fetchAllPool = fetchAllPool;
exports.fetchAssetDepositReceipt = fetchAssetDepositReceipt;
exports.fetchAssetDepositReceiptFromSeeds = fetchAssetDepositReceiptFromSeeds;
exports.fetchMaybeAssetDepositReceipt = fetchMaybeAssetDepositReceipt;
exports.fetchMaybeAssetDepositReceiptFromSeeds = fetchMaybeAssetDepositReceiptFromSeeds;
exports.fetchMaybeNftDepositReceipt = fetchMaybeNftDepositReceipt;
exports.fetchMaybeNftDepositReceiptFromSeeds = fetchMaybeNftDepositReceiptFromSeeds;
exports.fetchMaybePool = fetchMaybePool;
exports.fetchMaybePoolFromSeeds = fetchMaybePoolFromSeeds;
exports.fetchNftDepositReceipt = fetchNftDepositReceipt;
exports.fetchNftDepositReceiptFromSeeds = fetchNftDepositReceiptFromSeeds;
exports.fetchPool = fetchPool;
exports.fetchPoolFromSeeds = fetchPoolFromSeeds;
exports.findAssetDepositReceiptPda = findAssetDepositReceiptPda;
exports.findNftDepositReceiptPda = findNftDepositReceiptPda;
exports.findPoolPda = findPoolPda;
exports.getAmountOfBids = getAmountOfBids;
exports.getAssetDepositReceiptCodec = getAssetDepositReceiptCodec;
exports.getAssetDepositReceiptDecoder = getAssetDepositReceiptDecoder;
exports.getAssetDepositReceiptDiscriminatorBytes = getAssetDepositReceiptDiscriminatorBytes;
exports.getAssetDepositReceiptEncoder = getAssetDepositReceiptEncoder;
exports.getAssetDepositReceiptSize = getAssetDepositReceiptSize;
exports.getAuthorizationDataLocalCodec = getAuthorizationDataLocalCodec;
exports.getAuthorizationDataLocalDecoder = getAuthorizationDataLocalDecoder;
exports.getAuthorizationDataLocalEncoder = getAuthorizationDataLocalEncoder;
exports.getBuyNftCoreDiscriminatorBytes = getBuyNftCoreDiscriminatorBytes;
exports.getBuyNftCoreInstruction = getBuyNftCoreInstruction;
exports.getBuyNftCoreInstructionAsync = getBuyNftCoreInstructionAsync;
exports.getBuyNftCoreInstructionDataCodec = getBuyNftCoreInstructionDataCodec;
exports.getBuyNftCoreInstructionDataDecoder = getBuyNftCoreInstructionDataDecoder;
exports.getBuyNftCoreInstructionDataEncoder = getBuyNftCoreInstructionDataEncoder;
exports.getBuyNftDiscriminatorBytes = getBuyNftDiscriminatorBytes;
exports.getBuyNftInstruction = getBuyNftInstruction;
exports.getBuyNftInstructionAsync = getBuyNftInstructionAsync;
exports.getBuyNftInstructionDataCodec = getBuyNftInstructionDataCodec;
exports.getBuyNftInstructionDataDecoder = getBuyNftInstructionDataDecoder;
exports.getBuyNftInstructionDataEncoder = getBuyNftInstructionDataEncoder;
exports.getBuyNftT22DiscriminatorBytes = getBuyNftT22DiscriminatorBytes;
exports.getBuyNftT22Instruction = getBuyNftT22Instruction;
exports.getBuyNftT22InstructionAsync = getBuyNftT22InstructionAsync;
exports.getBuyNftT22InstructionDataCodec = getBuyNftT22InstructionDataCodec;
exports.getBuyNftT22InstructionDataDecoder = getBuyNftT22InstructionDataDecoder;
exports.getBuyNftT22InstructionDataEncoder = getBuyNftT22InstructionDataEncoder;
exports.getBuySellEventCodec = getBuySellEventCodec;
exports.getBuySellEventDecoder = getBuySellEventDecoder;
exports.getBuySellEventEncoder = getBuySellEventEncoder;
exports.getCloseExpiredPoolDiscriminatorBytes = getCloseExpiredPoolDiscriminatorBytes;
exports.getCloseExpiredPoolInstruction = getCloseExpiredPoolInstruction;
exports.getCloseExpiredPoolInstructionDataCodec = getCloseExpiredPoolInstructionDataCodec;
exports.getCloseExpiredPoolInstructionDataDecoder = getCloseExpiredPoolInstructionDataDecoder;
exports.getCloseExpiredPoolInstructionDataEncoder = getCloseExpiredPoolInstructionDataEncoder;
exports.getClosePoolDiscriminatorBytes = getClosePoolDiscriminatorBytes;
exports.getClosePoolInstruction = getClosePoolInstruction;
exports.getClosePoolInstructionDataCodec = getClosePoolInstructionDataCodec;
exports.getClosePoolInstructionDataDecoder = getClosePoolInstructionDataDecoder;
exports.getClosePoolInstructionDataEncoder = getClosePoolInstructionDataEncoder;
exports.getCreatePoolDiscriminatorBytes = getCreatePoolDiscriminatorBytes;
exports.getCreatePoolInstruction = getCreatePoolInstruction;
exports.getCreatePoolInstructionAsync = getCreatePoolInstructionAsync;
exports.getCreatePoolInstructionDataCodec = getCreatePoolInstructionDataCodec;
exports.getCreatePoolInstructionDataDecoder = getCreatePoolInstructionDataDecoder;
exports.getCreatePoolInstructionDataEncoder = getCreatePoolInstructionDataEncoder;
exports.getCurrencyCodec = getCurrencyCodec;
exports.getCurrencyDecoder = getCurrencyDecoder;
exports.getCurrencyEncoder = getCurrencyEncoder;
exports.getCurrentAskPrice = getCurrentAskPrice;
exports.getCurrentBidPrice = getCurrentBidPrice;
exports.getCurrentBidPriceSync = getCurrentBidPriceSync;
exports.getCurveTypeCodec = getCurveTypeCodec;
exports.getCurveTypeDecoder = getCurveTypeDecoder;
exports.getCurveTypeEncoder = getCurveTypeEncoder;
exports.getDepositNftCoreDiscriminatorBytes = getDepositNftCoreDiscriminatorBytes;
exports.getDepositNftCoreInstruction = getDepositNftCoreInstruction;
exports.getDepositNftCoreInstructionAsync = getDepositNftCoreInstructionAsync;
exports.getDepositNftCoreInstructionDataCodec = getDepositNftCoreInstructionDataCodec;
exports.getDepositNftCoreInstructionDataDecoder = getDepositNftCoreInstructionDataDecoder;
exports.getDepositNftCoreInstructionDataEncoder = getDepositNftCoreInstructionDataEncoder;
exports.getDepositNftDiscriminatorBytes = getDepositNftDiscriminatorBytes;
exports.getDepositNftInstruction = getDepositNftInstruction;
exports.getDepositNftInstructionAsync = getDepositNftInstructionAsync;
exports.getDepositNftInstructionDataCodec = getDepositNftInstructionDataCodec;
exports.getDepositNftInstructionDataDecoder = getDepositNftInstructionDataDecoder;
exports.getDepositNftInstructionDataEncoder = getDepositNftInstructionDataEncoder;
exports.getDepositNftT22DiscriminatorBytes = getDepositNftT22DiscriminatorBytes;
exports.getDepositNftT22Instruction = getDepositNftT22Instruction;
exports.getDepositNftT22InstructionAsync = getDepositNftT22InstructionAsync;
exports.getDepositNftT22InstructionDataCodec = getDepositNftT22InstructionDataCodec;
exports.getDepositNftT22InstructionDataDecoder = getDepositNftT22InstructionDataDecoder;
exports.getDepositNftT22InstructionDataEncoder = getDepositNftT22InstructionDataEncoder;
exports.getDepositSolDiscriminatorBytes = getDepositSolDiscriminatorBytes;
exports.getDepositSolInstruction = getDepositSolInstruction;
exports.getDepositSolInstructionDataCodec = getDepositSolInstructionDataCodec;
exports.getDepositSolInstructionDataDecoder = getDepositSolInstructionDataDecoder;
exports.getDepositSolInstructionDataEncoder = getDepositSolInstructionDataEncoder;
exports.getDirectionCodec = getDirectionCodec;
exports.getDirectionDecoder = getDirectionDecoder;
exports.getDirectionEncoder = getDirectionEncoder;
exports.getEditPoolConfigCodec = getEditPoolConfigCodec;
exports.getEditPoolConfigDecoder = getEditPoolConfigDecoder;
exports.getEditPoolConfigEncoder = getEditPoolConfigEncoder;
exports.getEditPoolDiscriminatorBytes = getEditPoolDiscriminatorBytes;
exports.getEditPoolInstruction = getEditPoolInstruction;
exports.getEditPoolInstructionDataCodec = getEditPoolInstructionDataCodec;
exports.getEditPoolInstructionDataDecoder = getEditPoolInstructionDataDecoder;
exports.getEditPoolInstructionDataEncoder = getEditPoolInstructionDataEncoder;
exports.getNftDepositReceiptCodec = getNftDepositReceiptCodec;
exports.getNftDepositReceiptDecoder = getNftDepositReceiptDecoder;
exports.getNftDepositReceiptDiscriminatorBytes = getNftDepositReceiptDiscriminatorBytes;
exports.getNftDepositReceiptEncoder = getNftDepositReceiptEncoder;
exports.getNftDepositReceiptSize = getNftDepositReceiptSize;
exports.getNullableAddressCodec = getNullableAddressCodec;
exports.getNullableAddressDecoder = getNullableAddressDecoder;
exports.getNullableAddressEncoder = getNullableAddressEncoder;
exports.getNullableU16Codec = getNullableU16Codec;
exports.getNullableU16Decoder = getNullableU16Decoder;
exports.getNullableU16Encoder = getNullableU16Encoder;
exports.getPayloadTypeLocalCodec = getPayloadTypeLocalCodec;
exports.getPayloadTypeLocalDecoder = getPayloadTypeLocalDecoder;
exports.getPayloadTypeLocalEncoder = getPayloadTypeLocalEncoder;
exports.getPoolCodec = getPoolCodec;
exports.getPoolConfigCodec = getPoolConfigCodec;
exports.getPoolConfigDecoder = getPoolConfigDecoder;
exports.getPoolConfigEncoder = getPoolConfigEncoder;
exports.getPoolDecoder = getPoolDecoder;
exports.getPoolDiscriminatorBytes = getPoolDiscriminatorBytes;
exports.getPoolEncoder = getPoolEncoder;
exports.getPoolSize = getPoolSize;
exports.getPoolStatsCodec = getPoolStatsCodec;
exports.getPoolStatsDecoder = getPoolStatsDecoder;
exports.getPoolStatsEncoder = getPoolStatsEncoder;
exports.getPoolTypeCodec = getPoolTypeCodec;
exports.getPoolTypeDecoder = getPoolTypeDecoder;
exports.getPoolTypeEncoder = getPoolTypeEncoder;
exports.getProofInfoLocalCodec = getProofInfoLocalCodec;
exports.getProofInfoLocalDecoder = getProofInfoLocalDecoder;
exports.getProofInfoLocalEncoder = getProofInfoLocalEncoder;
exports.getSeedsVecLocalCodec = getSeedsVecLocalCodec;
exports.getSeedsVecLocalDecoder = getSeedsVecLocalDecoder;
exports.getSeedsVecLocalEncoder = getSeedsVecLocalEncoder;
exports.getSellNftTokenPoolCoreDiscriminatorBytes = getSellNftTokenPoolCoreDiscriminatorBytes;
exports.getSellNftTokenPoolCoreInstruction = getSellNftTokenPoolCoreInstruction;
exports.getSellNftTokenPoolCoreInstructionAsync = getSellNftTokenPoolCoreInstructionAsync;
exports.getSellNftTokenPoolCoreInstructionDataCodec = getSellNftTokenPoolCoreInstructionDataCodec;
exports.getSellNftTokenPoolCoreInstructionDataDecoder = getSellNftTokenPoolCoreInstructionDataDecoder;
exports.getSellNftTokenPoolCoreInstructionDataEncoder = getSellNftTokenPoolCoreInstructionDataEncoder;
exports.getSellNftTokenPoolDiscriminatorBytes = getSellNftTokenPoolDiscriminatorBytes;
exports.getSellNftTokenPoolInstruction = getSellNftTokenPoolInstruction;
exports.getSellNftTokenPoolInstructionAsync = getSellNftTokenPoolInstructionAsync;
exports.getSellNftTokenPoolInstructionDataCodec = getSellNftTokenPoolInstructionDataCodec;
exports.getSellNftTokenPoolInstructionDataDecoder = getSellNftTokenPoolInstructionDataDecoder;
exports.getSellNftTokenPoolInstructionDataEncoder = getSellNftTokenPoolInstructionDataEncoder;
exports.getSellNftTokenPoolT22DiscriminatorBytes = getSellNftTokenPoolT22DiscriminatorBytes;
exports.getSellNftTokenPoolT22Instruction = getSellNftTokenPoolT22Instruction;
exports.getSellNftTokenPoolT22InstructionAsync = getSellNftTokenPoolT22InstructionAsync;
exports.getSellNftTokenPoolT22InstructionDataCodec = getSellNftTokenPoolT22InstructionDataCodec;
exports.getSellNftTokenPoolT22InstructionDataDecoder = getSellNftTokenPoolT22InstructionDataDecoder;
exports.getSellNftTokenPoolT22InstructionDataEncoder = getSellNftTokenPoolT22InstructionDataEncoder;
exports.getSellNftTradePoolCoreDiscriminatorBytes = getSellNftTradePoolCoreDiscriminatorBytes;
exports.getSellNftTradePoolCoreInstruction = getSellNftTradePoolCoreInstruction;
exports.getSellNftTradePoolCoreInstructionAsync = getSellNftTradePoolCoreInstructionAsync;
exports.getSellNftTradePoolCoreInstructionDataCodec = getSellNftTradePoolCoreInstructionDataCodec;
exports.getSellNftTradePoolCoreInstructionDataDecoder = getSellNftTradePoolCoreInstructionDataDecoder;
exports.getSellNftTradePoolCoreInstructionDataEncoder = getSellNftTradePoolCoreInstructionDataEncoder;
exports.getSellNftTradePoolDiscriminatorBytes = getSellNftTradePoolDiscriminatorBytes;
exports.getSellNftTradePoolInstruction = getSellNftTradePoolInstruction;
exports.getSellNftTradePoolInstructionAsync = getSellNftTradePoolInstructionAsync;
exports.getSellNftTradePoolInstructionDataCodec = getSellNftTradePoolInstructionDataCodec;
exports.getSellNftTradePoolInstructionDataDecoder = getSellNftTradePoolInstructionDataDecoder;
exports.getSellNftTradePoolInstructionDataEncoder = getSellNftTradePoolInstructionDataEncoder;
exports.getSellNftTradePoolT22DiscriminatorBytes = getSellNftTradePoolT22DiscriminatorBytes;
exports.getSellNftTradePoolT22Instruction = getSellNftTradePoolT22Instruction;
exports.getSellNftTradePoolT22InstructionAsync = getSellNftTradePoolT22InstructionAsync;
exports.getSellNftTradePoolT22InstructionDataCodec = getSellNftTradePoolT22InstructionDataCodec;
exports.getSellNftTradePoolT22InstructionDataDecoder = getSellNftTradePoolT22InstructionDataDecoder;
exports.getSellNftTradePoolT22InstructionDataEncoder = getSellNftTradePoolT22InstructionDataEncoder;
exports.getTAmmEventCodec = getTAmmEventCodec;
exports.getTAmmEventDecoder = getTAmmEventDecoder;
exports.getTAmmEventEncoder = getTAmmEventEncoder;
exports.getTaggedPayloadCodec = getTaggedPayloadCodec;
exports.getTaggedPayloadDecoder = getTaggedPayloadDecoder;
exports.getTaggedPayloadEncoder = getTaggedPayloadEncoder;
exports.getTakerSideCodec = getTakerSideCodec;
exports.getTakerSideDecoder = getTakerSideDecoder;
exports.getTakerSideEncoder = getTakerSideEncoder;
exports.getTammNoopDiscriminatorBytes = getTammNoopDiscriminatorBytes;
exports.getTammNoopInstruction = getTammNoopInstruction;
exports.getTammNoopInstructionDataCodec = getTammNoopInstructionDataCodec;
exports.getTammNoopInstructionDataDecoder = getTammNoopInstructionDataDecoder;
exports.getTammNoopInstructionDataEncoder = getTammNoopInstructionDataEncoder;
exports.getTensorAmmErrorMessage = getTensorAmmErrorMessage;
exports.getTransferDirectionCodec = getTransferDirectionCodec;
exports.getTransferDirectionDecoder = getTransferDirectionDecoder;
exports.getTransferDirectionEncoder = getTransferDirectionEncoder;
exports.getWithdrawNftCoreDiscriminatorBytes = getWithdrawNftCoreDiscriminatorBytes;
exports.getWithdrawNftCoreInstruction = getWithdrawNftCoreInstruction;
exports.getWithdrawNftCoreInstructionAsync = getWithdrawNftCoreInstructionAsync;
exports.getWithdrawNftCoreInstructionDataCodec = getWithdrawNftCoreInstructionDataCodec;
exports.getWithdrawNftCoreInstructionDataDecoder = getWithdrawNftCoreInstructionDataDecoder;
exports.getWithdrawNftCoreInstructionDataEncoder = getWithdrawNftCoreInstructionDataEncoder;
exports.getWithdrawNftDiscriminatorBytes = getWithdrawNftDiscriminatorBytes;
exports.getWithdrawNftInstruction = getWithdrawNftInstruction;
exports.getWithdrawNftInstructionAsync = getWithdrawNftInstructionAsync;
exports.getWithdrawNftInstructionDataCodec = getWithdrawNftInstructionDataCodec;
exports.getWithdrawNftInstructionDataDecoder = getWithdrawNftInstructionDataDecoder;
exports.getWithdrawNftInstructionDataEncoder = getWithdrawNftInstructionDataEncoder;
exports.getWithdrawNftT22DiscriminatorBytes = getWithdrawNftT22DiscriminatorBytes;
exports.getWithdrawNftT22Instruction = getWithdrawNftT22Instruction;
exports.getWithdrawNftT22InstructionAsync = getWithdrawNftT22InstructionAsync;
exports.getWithdrawNftT22InstructionDataCodec = getWithdrawNftT22InstructionDataCodec;
exports.getWithdrawNftT22InstructionDataDecoder = getWithdrawNftT22InstructionDataDecoder;
exports.getWithdrawNftT22InstructionDataEncoder = getWithdrawNftT22InstructionDataEncoder;
exports.getWithdrawSolDiscriminatorBytes = getWithdrawSolDiscriminatorBytes;
exports.getWithdrawSolInstruction = getWithdrawSolInstruction;
exports.getWithdrawSolInstructionDataCodec = getWithdrawSolInstructionDataCodec;
exports.getWithdrawSolInstructionDataDecoder = getWithdrawSolInstructionDataDecoder;
exports.getWithdrawSolInstructionDataEncoder = getWithdrawSolInstructionDataEncoder;
exports.identifyTensorAmmAccount = identifyTensorAmmAccount;
exports.identifyTensorAmmInstruction = identifyTensorAmmInstruction;
exports.isPayloadTypeLocal = isPayloadTypeLocal;
exports.isSol = isSol;
exports.isTAmmEvent = isTAmmEvent;
exports.isTensorAmmError = isTensorAmmError;
exports.parseBuyNftCoreInstruction = parseBuyNftCoreInstruction;
exports.parseBuyNftInstruction = parseBuyNftInstruction;
exports.parseBuyNftT22Instruction = parseBuyNftT22Instruction;
exports.parseCloseExpiredPoolInstruction = parseCloseExpiredPoolInstruction;
exports.parseClosePoolInstruction = parseClosePoolInstruction;
exports.parseCreatePoolInstruction = parseCreatePoolInstruction;
exports.parseDepositNftCoreInstruction = parseDepositNftCoreInstruction;
exports.parseDepositNftInstruction = parseDepositNftInstruction;
exports.parseDepositNftT22Instruction = parseDepositNftT22Instruction;
exports.parseDepositSolInstruction = parseDepositSolInstruction;
exports.parseEditPoolInstruction = parseEditPoolInstruction;
exports.parseSellNftTokenPoolCoreInstruction = parseSellNftTokenPoolCoreInstruction;
exports.parseSellNftTokenPoolInstruction = parseSellNftTokenPoolInstruction;
exports.parseSellNftTokenPoolT22Instruction = parseSellNftTokenPoolT22Instruction;
exports.parseSellNftTradePoolCoreInstruction = parseSellNftTradePoolCoreInstruction;
exports.parseSellNftTradePoolInstruction = parseSellNftTradePoolInstruction;
exports.parseSellNftTradePoolT22Instruction = parseSellNftTradePoolT22Instruction;
exports.parseTammNoopInstruction = parseTammNoopInstruction;
exports.parseWithdrawNftCoreInstruction = parseWithdrawNftCoreInstruction;
exports.parseWithdrawNftInstruction = parseWithdrawNftInstruction;
exports.parseWithdrawNftT22Instruction = parseWithdrawNftT22Instruction;
exports.parseWithdrawSolInstruction = parseWithdrawSolInstruction;
exports.payloadTypeLocal = payloadTypeLocal;
exports.resolveEdition = resolveEdition;
exports.resolveFeeVaultPdaFromPool = resolveFeeVaultPdaFromPool;
exports.resolvePoolAssetReceipt = resolvePoolAssetReceipt;
exports.resolvePoolIdOnCreate = resolvePoolIdOnCreate;
exports.resolveTakerAta = resolveTakerAta;
exports.resolveTakerTokenRecordFromTokenStandard = resolveTakerTokenRecordFromTokenStandard;
exports.resolveUserTokenRecordFromTokenStandard = resolveUserTokenRecordFromTokenStandard;
exports.solCurrency = solCurrency;
exports.tAmmEvent = tAmmEvent;
//# sourceMappingURL=index.js.map
//# sourceMappingURL=index.js.map