import { address, getProgramDerivedAddress, getUtf8Encoder, getAddressEncoder, fixEncoderSize, getBytesEncoder, transformEncoder, getStructEncoder, getU8Encoder, getStructDecoder, fixDecoderSize, getBytesDecoder, getU8Decoder, getAddressDecoder, combineCodec, decodeAccount, assertAccountExists, fetchEncodedAccount, assertAccountsExist, fetchEncodedAccounts, createEncoder, createDecoder, getU16Encoder, getU16Decoder, getArrayEncoder, getArrayDecoder, getU64Encoder, getU64Decoder, getEnumEncoder, getEnumDecoder, getBooleanEncoder, getBooleanDecoder, getDiscriminatedUnionEncoder, getTupleEncoder, getDiscriminatedUnionDecoder, getTupleDecoder, getU32Encoder, getU32Decoder, addEncoderSizePrefix, addDecoderSizePrefix, getUtf8Decoder, getI64Encoder, getI32Encoder, getI64Decoder, getI32Decoder, containsBytes, isProgramError, getOptionEncoder, none, getOptionDecoder, AccountRole, isTransactionSigner as isTransactionSigner$1, upgradeRoleToSigner } from '@solana/web3.js';
import '@solana-program/token';
import { findAssociatedTokenAccountPda, findFeeVaultPda, findNftReceiptPda, findEditionPda, resolveEscrowProgramFromSharedEscrow, resolveMetadata, resolvePoolAta, resolvePoolTokenRecordFromTokenStandard, resolveTokenMetadataProgramFromTokenStandard, resolveSysvarInstructionsFromTokenStandard, resolveAuthorizationRulesProgramFromTokenStandard, resolveOwnerAta, resolveOwnerTokenRecordFromTokenStandard } from '@tensor-foundation/resolvers';

var __getOwnPropNames = Object.getOwnPropertyNames;
var __esm = (fn, res) => function __init() {
  return fn && (res = (0, fn[__getOwnPropNames(fn)[0]])(fn = 0)), res;
};

// env-shim.ts
var init_env_shim = __esm({
  "env-shim.ts"() {
  }
});

// src/index.ts
init_env_shim();

// src/generated/accounts/assetDepositReceipt.ts
init_env_shim();

// src/generated/pdas/assetDepositReceipt.ts
init_env_shim();
async function findAssetDepositReceiptPda(seeds, config = {}) {
  const {
    programAddress = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("nft_receipt"),
      getAddressEncoder().encode(seeds.asset),
      getAddressEncoder().encode(seeds.pool)
    ]
  });
}

// src/generated/pdas/nftDepositReceipt.ts
init_env_shim();
async function findNftDepositReceiptPda(seeds, config = {}) {
  const {
    programAddress = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("nft_receipt"),
      getAddressEncoder().encode(seeds.mint),
      getAddressEncoder().encode(seeds.pool)
    ]
  });
}

// src/generated/pdas/pool.ts
init_env_shim();
async function findPoolPda(seeds, config = {}) {
  const {
    programAddress = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("pool"),
      getAddressEncoder().encode(seeds.owner),
      fixEncoderSize(getBytesEncoder(), 32).encode(seeds.poolId)
    ]
  });
}

// src/generated/accounts/assetDepositReceipt.ts
var ASSET_DEPOSIT_RECEIPT_DISCRIMINATOR = new Uint8Array([
  147,
  18,
  99,
  58,
  249,
  8,
  196,
  221
]);
function getAssetDepositReceiptDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    ASSET_DEPOSIT_RECEIPT_DISCRIMINATOR
  );
}
function getAssetDepositReceiptEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["bump", getU8Encoder()],
      ["asset", getAddressEncoder()],
      ["pool", getAddressEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: ASSET_DEPOSIT_RECEIPT_DISCRIMINATOR
    })
  );
}
function getAssetDepositReceiptDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["bump", getU8Decoder()],
    ["asset", getAddressDecoder()],
    ["pool", getAddressDecoder()]
  ]);
}
function getAssetDepositReceiptCodec() {
  return combineCodec(
    getAssetDepositReceiptEncoder(),
    getAssetDepositReceiptDecoder()
  );
}
function decodeAssetDepositReceipt(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getAssetDepositReceiptDecoder()
  );
}
async function fetchAssetDepositReceipt(rpc, address4, config) {
  const maybeAccount = await fetchMaybeAssetDepositReceipt(
    rpc,
    address4,
    config
  );
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeAssetDepositReceipt(rpc, address4, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address4, config);
  return decodeAssetDepositReceipt(maybeAccount);
}
async function fetchAllAssetDepositReceipt(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeAssetDepositReceipt(
    rpc,
    addresses,
    config
  );
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeAssetDepositReceipt(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeAssetDepositReceipt(maybeAccount)
  );
}
function getAssetDepositReceiptSize() {
  return 73;
}
async function fetchAssetDepositReceiptFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeAssetDepositReceiptFromSeeds(
    rpc,
    seeds,
    config
  );
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeAssetDepositReceiptFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address4] = await findAssetDepositReceiptPda(seeds, { programAddress });
  return await fetchMaybeAssetDepositReceipt(rpc, address4, fetchConfig);
}

// src/generated/accounts/nftDepositReceipt.ts
init_env_shim();
var NFT_DEPOSIT_RECEIPT_DISCRIMINATOR = new Uint8Array([
  206,
  255,
  132,
  254,
  67,
  78,
  62,
  96
]);
function getNftDepositReceiptDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    NFT_DEPOSIT_RECEIPT_DISCRIMINATOR
  );
}
function getNftDepositReceiptEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["bump", getU8Encoder()],
      ["mint", getAddressEncoder()],
      ["pool", getAddressEncoder()]
    ]),
    (value) => ({ ...value, discriminator: NFT_DEPOSIT_RECEIPT_DISCRIMINATOR })
  );
}
function getNftDepositReceiptDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["bump", getU8Decoder()],
    ["mint", getAddressDecoder()],
    ["pool", getAddressDecoder()]
  ]);
}
function getNftDepositReceiptCodec() {
  return combineCodec(
    getNftDepositReceiptEncoder(),
    getNftDepositReceiptDecoder()
  );
}
function decodeNftDepositReceipt(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getNftDepositReceiptDecoder()
  );
}
async function fetchNftDepositReceipt(rpc, address4, config) {
  const maybeAccount = await fetchMaybeNftDepositReceipt(rpc, address4, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeNftDepositReceipt(rpc, address4, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address4, config);
  return decodeNftDepositReceipt(maybeAccount);
}
async function fetchAllNftDepositReceipt(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeNftDepositReceipt(
    rpc,
    addresses,
    config
  );
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeNftDepositReceipt(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeNftDepositReceipt(maybeAccount)
  );
}
function getNftDepositReceiptSize() {
  return 73;
}
async function fetchNftDepositReceiptFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeNftDepositReceiptFromSeeds(
    rpc,
    seeds,
    config
  );
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeNftDepositReceiptFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address4] = await findNftDepositReceiptPda(seeds, { programAddress });
  return await fetchMaybeNftDepositReceipt(rpc, address4, fetchConfig);
}

// src/generated/accounts/pool.ts
init_env_shim();

// src/hooked/currency.ts
init_env_shim();
var SOL_ADDRESS = address("11111111111111111111111111111111");
var isSol = (currency) => currency === SOL_ADDRESS;
var solCurrency = () => SOL_ADDRESS;
var getCurrencyEncoder = () => getAddressEncoder();
var getCurrencyDecoder = () => getAddressDecoder();
var getCurrencyCodec = () => combineCodec(getCurrencyEncoder(), getCurrencyDecoder());

// src/hooked/helpers.ts
init_env_shim();

// src/hooked/nullableAddress.ts
init_env_shim();
var DEFAULT_ADDRESS = address("11111111111111111111111111111111");
var getNullableAddressEncoder = () => createEncoder({
  fixedSize: 32,
  write(value, bytes, offset) {
    if (value === null) {
      bytes.set(getAddressEncoder().encode(DEFAULT_ADDRESS), offset);
    } else {
      bytes.set(getAddressEncoder().encode(value), offset);
    }
    return offset + 32;
  }
});
var getNullableAddressDecoder = () => createDecoder({
  fixedSize: 32,
  read(bytes, offset) {
    if (getAddressDecoder().decode(bytes, offset) === DEFAULT_ADDRESS) {
      return [null, offset + 32];
    } else {
      return [getAddressDecoder().decode(bytes, offset), offset + 32];
    }
  }
});
var getNullableAddressCodec = () => combineCodec(getNullableAddressEncoder(), getNullableAddressDecoder());

// src/hooked/helpers.ts
var BASIS_POINTS = 10000n;
var BASIS_POINTS_DECIMAL_OFFSET = 4;
var BID_AMOUNT_LIMIT = 1e3;
function calculateAmountForQuantity({
  pool,
  quantity,
  side
}) {
  if (quantity < 1) return 0;
  if (side === 1 /* Sell */) {
    if (pool.config.poolType === 1 /* NFT */) return 0;
    const excludeMMFee = pool.config.poolType === 2 /* Trade */ && !pool.config.mmCompoundFees;
    if (pool.config.curveType === 0 /* Linear */) {
      const currentPrice = calculatePrice({
        pool,
        side: 1 /* Sell */,
        royaltyFeeBps: 0,
        extraOffset: 0,
        excludeMMFee
      });
      if (quantity === 1) return currentPrice;
      const maxPossibleBidsBeforeZero = pool.config.delta <= 0n ? quantity : 1 + Number(BigInt(currentPrice) / pool.config.delta);
      quantity = Math.min(quantity, maxPossibleBidsBeforeZero);
      const bases = currentPrice * quantity;
      const deltas = Number(pool.config.delta) * (quantity * (quantity - 1)) / 2;
      return bases - deltas;
    } else {
      let totalPrice = 0;
      let i = 0;
      while (quantity > 0) {
        totalPrice += calculatePrice({
          pool,
          side: 1 /* Sell */,
          royaltyFeeBps: 0,
          extraOffset: i,
          excludeMMFee
        });
        quantity -= 1;
        if (totalPrice === 0) break;
        i += 1;
      }
      return totalPrice;
    }
  } else {
    if (pool.config.poolType === 0 /* Token */) return 0;
    let totalPrice = 0;
    let i = 0;
    while (quantity > 0) {
      totalPrice += calculatePrice({
        pool,
        side: 0 /* Buy */,
        royaltyFeeBps: 0,
        extraOffset: i,
        excludeMMFee: false
      });
      quantity -= 1;
      i += 1;
    }
    return totalPrice;
  }
}
function getAmountOfBids({
  pool,
  availableLamports
}) {
  if (pool.config.poolType === 1 /* NFT */) return 0;
  let amountOfBidsWithoutMaxCount;
  const excludeMMFee = pool.config.poolType === 2 /* Trade */ && !pool.config.mmCompoundFees;
  if (pool.config.curveType === 0 /* Linear */) {
    const currentPrice = calculatePrice({
      pool,
      side: 1 /* Sell */,
      royaltyFeeBps: 0,
      extraOffset: 0,
      excludeMMFee
    });
    if (currentPrice < 0) return 0;
    let maxPossibleBidsBeforeZero = pool.config.delta <= 0n ? BID_AMOUNT_LIMIT : 1 + Number(BigInt(currentPrice) / pool.config.delta);
    maxPossibleBidsBeforeZero = Math.min(
      maxPossibleBidsBeforeZero,
      BID_AMOUNT_LIMIT
    );
    let bidCount = 0;
    let accumulatedPrice = 0n;
    while (accumulatedPrice < BigInt(availableLamports) && bidCount < maxPossibleBidsBeforeZero + 1) {
      const price = calculatePrice({
        pool,
        side: 1 /* Sell */,
        royaltyFeeBps: 0,
        extraOffset: bidCount,
        excludeMMFee
      });
      accumulatedPrice += BigInt(price);
      bidCount += 1;
    }
    amountOfBidsWithoutMaxCount = Math.min(
      bidCount - 1,
      maxPossibleBidsBeforeZero
    );
  } else {
    let bidCount = 0;
    let accumulatedPrice = 0n;
    while (accumulatedPrice < BigInt(availableLamports) && bidCount < BID_AMOUNT_LIMIT + 1) {
      const price = calculatePrice({
        pool,
        side: 1 /* Sell */,
        royaltyFeeBps: 0,
        extraOffset: bidCount,
        excludeMMFee
      });
      accumulatedPrice += BigInt(price);
      bidCount += 1;
    }
    amountOfBidsWithoutMaxCount = bidCount - 1;
  }
  return isMaxTakerSellCountReached(pool) ? Math.min(
    amountOfBidsWithoutMaxCount,
    pool.maxTakerSellCount + pool.priceOffset
  ) : amountOfBidsWithoutMaxCount;
}
function getCurrentAskPrice({
  pool,
  royaltyFeeBps,
  extraOffset = 0,
  excludeMMFee = false
}) {
  if (pool.nftsHeld < 1) return null;
  if (isNotFulfillable({ pool, side: 0 /* Buy */ })) return null;
  return calculatePrice({
    pool,
    side: 0 /* Buy */,
    royaltyFeeBps,
    extraOffset,
    excludeMMFee
  });
}
function getCurrentBidPriceSync({
  pool,
  availableLamports,
  royaltyFeeBps,
  extraOffset = 0,
  excludeMMFee = false
}) {
  const bidPrice = calculatePrice({
    pool,
    side: 1 /* Sell */,
    royaltyFeeBps,
    extraOffset,
    excludeMMFee
  });
  if (bidPrice < 1) return 0;
  if (isNotFulfillable({ pool, side: 1 /* Sell */ })) return null;
  return availableLamports >= bidPrice ? bidPrice : null;
}
async function getCurrentBidPrice({
  rpc,
  pool,
  royaltyFeeBps,
  extraOffset = 0,
  excludeMMFee = false
}) {
  if (isNotFulfillable({ pool, side: 1 /* Sell */ })) return null;
  const bidPrice = calculatePrice({
    pool,
    side: 1 /* Sell */,
    royaltyFeeBps,
    extraOffset,
    excludeMMFee
  });
  if (bidPrice === null) return null;
  if (bidPrice < 1) return 0;
  if (!pool.sharedEscrow || pool.sharedEscrow === DEFAULT_ADDRESS)
    return pool.amount >= bidPrice ? bidPrice : null;
  const [escrowLamports, escrowDataLength] = await rpc.getAccountInfo(pool.sharedEscrow, { encoding: "base64" }).send().then((resp) => {
    const dataLength = resp.value?.data ? Buffer.from(resp.value.data[0], "base64").length : void 0;
    return [resp.value?.lamports, dataLength];
  });
  if (!escrowLamports || !escrowDataLength) return null;
  const rentExemption = await rpc.getMinimumBalanceForRentExemption(BigInt(escrowDataLength)).send();
  return BigInt(escrowLamports) - rentExemption >= bidPrice ? bidPrice : null;
}
function calculatePrice({
  pool,
  side,
  royaltyFeeBps,
  extraOffset = 0,
  excludeMMFee = false
}) {
  const extraOffsetNormalized = Math.abs(extraOffset);
  const tradePoolOffset = pool.config.poolType === 2 /* Trade */ && side === 1 /* Sell */ ? -1 : 0;
  const offset = pool.priceOffset + tradePoolOffset + (side === 1 /* Sell */ ? -extraOffsetNormalized : extraOffsetNormalized);
  const startingPrice = pool.config.startingPrice;
  const delta = pool.config.delta;
  let resultPrice;
  if (pool.config.curveType === 1 /* Exponential */) {
    const base = BASIS_POINTS + delta;
    const exponent = BigInt(Math.abs(offset));
    const [scaling, decimalOffset] = powerBpsAsBigInt_12DecimalMantissaPrecision(base, exponent);
    let resultPriceIntermediate;
    if (offset < 0) {
      const divident = startingPrice * 10n ** decimalOffset;
      const divisor = scaling;
      resultPriceIntermediate = divident / divisor + BigInt(+needsRoundingAddedBack(divident, divisor, side));
    } else {
      const divident = startingPrice * scaling;
      const divisor = 10n ** decimalOffset;
      resultPriceIntermediate = divident / divisor + BigInt(+needsRoundingAddedBack(divident, divisor, side));
    }
    resultPrice = Number(resultPriceIntermediate);
  } else {
    resultPrice = Number(startingPrice + delta * BigInt(offset));
  }
  let resultPriceIncludingMmFees;
  if (pool.config.poolType === 2 /* Trade */ && !excludeMMFee) {
    const mmFees = BigInt(resultPrice) * BigInt(pool.config.mmFeeBps ?? 0) / BASIS_POINTS;
    resultPriceIncludingMmFees = side === 1 /* Sell */ ? Number(BigInt(resultPrice) - mmFees) : Number(BigInt(resultPrice) + mmFees);
  } else {
    resultPriceIncludingMmFees = resultPrice;
  }
  let resultPriceIncludingMmFeesAndRoyalties;
  if (royaltyFeeBps === 0) return resultPriceIncludingMmFees;
  else {
    const royalties = BigInt(resultPrice) * BigInt(royaltyFeeBps) / BASIS_POINTS;
    resultPriceIncludingMmFeesAndRoyalties = side === 1 /* Sell */ ? Number(BigInt(resultPriceIncludingMmFees) - royalties) : Number(BigInt(resultPriceIncludingMmFees) + royalties);
  }
  return resultPriceIncludingMmFeesAndRoyalties;
}
function powerBpsAsBigInt_12DecimalMantissaPrecision(base, exponent) {
  let result;
  let decimalOffset = BASIS_POINTS_DECIMAL_OFFSET;
  let resultDecimalOffset = BASIS_POINTS_DECIMAL_OFFSET;
  if (exponent === 0n)
    return [1n * BASIS_POINTS, 1n * BigInt(BASIS_POINTS_DECIMAL_OFFSET)];
  if (exponent % 2n === 1n) {
    result = base;
  } else {
    result = 1n * BASIS_POINTS;
  }
  let pow = base;
  exponent /= 2n;
  while (exponent > 0n) {
    pow *= pow;
    decimalOffset *= 2;
    [pow, decimalOffset] = cutTo12MantissaDecimals(pow, decimalOffset);
    if (exponent % 2n === 1n) {
      result *= pow;
      resultDecimalOffset += decimalOffset;
      [result, resultDecimalOffset] = cutTo12MantissaDecimals(
        result,
        resultDecimalOffset
      );
    }
    exponent /= 2n;
  }
  [result, resultDecimalOffset] = cutTo12MantissaDecimals(
    result,
    resultDecimalOffset
  );
  return [result, BigInt(resultDecimalOffset)];
}
var needsRoundingAddedBack = (divident, divisor, side) => {
  const remainder = divident % divisor;
  return remainder > 0 && side === 0 /* Buy */;
};
var cutTo12MantissaDecimals = (num, decimalOffset, withRounding = true) => {
  const decimalPrecision = 12;
  const exponentLength = num.toString(10).length - decimalOffset;
  let adjustedOffset = decimalOffset;
  let adjustedNum = num;
  if (decimalOffset > decimalPrecision) {
    adjustedNum = BigInt(
      num.toString(10).slice(0, exponentLength + decimalPrecision)
    );
    adjustedOffset = adjustedNum.toString(10).length - exponentLength;
  }
  adjustedNum += withRounding ? BigInt(+(parseInt(num.toString()[decimalPrecision + 1]) > 4)) : 0n;
  return [adjustedNum, adjustedOffset];
};
function isMaxTakerSellCountReached(pool) {
  return pool.priceOffset * -1 === pool.maxTakerSellCount && pool.maxTakerSellCount !== 0 && !!pool.sharedEscrow && pool.sharedEscrow !== DEFAULT_ADDRESS;
}
var isNotFulfillable = ({
  pool,
  side
}) => {
  return (
    // can't sell into PoolType.NFT
    pool.config.poolType === 1 /* NFT */ && side === 1 /* Sell */ || // can't buy from a PoolType.Token
    pool.config.poolType === 0 /* Token */ && side === 0 /* Buy */ || // if maxTakerSellCount is reached when pool is attached to margin acc,
    // pool can't fulfill more bids
    isMaxTakerSellCountReached(pool) && side === 1 /* Sell */
  );
};

// src/hooked/nullableNumber.ts
init_env_shim();
var getNullableU16Encoder = () => createEncoder({
  fixedSize: 2,
  write(value, bytes, offset) {
    if (value === null) {
      bytes.set(getU16Encoder().encode(0), offset);
    } else {
      bytes.set(getU16Encoder().encode(value), offset);
    }
    return offset + 2;
  }
});
var getNullableU16Decoder = () => createDecoder({
  fixedSize: 2,
  read(bytes, offset) {
    if (getU16Decoder().decode(bytes, offset) === 0) {
      return [null, offset + 2];
    } else {
      return [getU16Decoder().decode(bytes, offset), offset + 2];
    }
  }
});
var getNullableU16Codec = () => combineCodec(getNullableU16Encoder(), getNullableU16Decoder());

// src/hooked/resolvers.ts
init_env_shim();

// node_modules/.pnpm/@tensor-foundation+mpl-token-metadata@1.0.0-beta.1_bufferutil@4.0.8_fastestsmallesttextencode_fhlrog52xoqwrkk6nerzh6ehye/node_modules/@tensor-foundation/mpl-token-metadata/dist/src/index.mjs
init_env_shim();
var TokenStandard = /* @__PURE__ */ ((TokenStandard2) => {
  TokenStandard2[TokenStandard2["NonFungible"] = 0] = "NonFungible";
  TokenStandard2[TokenStandard2["FungibleAsset"] = 1] = "FungibleAsset";
  TokenStandard2[TokenStandard2["Fungible"] = 2] = "Fungible";
  TokenStandard2[TokenStandard2["NonFungibleEdition"] = 3] = "NonFungibleEdition";
  TokenStandard2[TokenStandard2["ProgrammableNonFungible"] = 4] = "ProgrammableNonFungible";
  TokenStandard2[TokenStandard2["ProgrammableNonFungibleEdition"] = 5] = "ProgrammableNonFungibleEdition";
  return TokenStandard2;
})(TokenStandard || {});
async function findTokenRecordPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint),
      getUtf8Encoder().encode("token_record"),
      getAddressEncoder().encode(seeds.token)
    ]
  });
}
if (process.env.NODE_ENV !== "production") ;

// src/generated/shared/index.ts
init_env_shim();
function expectSome(value) {
  if (value == null) {
    throw new Error("Expected a value but received null or undefined.");
  }
  return value;
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function expectTransactionSigner(value) {
  if (!value || !isTransactionSigner(value)) {
    throw new Error("Expected a TransactionSigner.");
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      return Object.freeze({
        address: programAddress,
        role: AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? AccountRole.WRITABLE : AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && isTransactionSigner$1(value);
}

// src/hooked/resolvers.ts
var resolveTakerAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.taker?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolvePoolIdOnCreate = (_) => {
  return new Uint8Array(32).map(() => Math.random() * 256 & 255);
};
var resolveFeeVaultPdaFromPool = async ({
  accounts
}) => {
  return {
    value: await findFeeVaultPda({
      address: expectAddress(accounts.pool?.value)
    })
  };
};
var resolvePoolAssetReceipt = async ({
  accounts
}) => {
  return {
    value: await findNftReceiptPda(
      {
        mint: expectAddress(accounts.asset?.value),
        state: expectAddress(accounts.pool?.value)
      },
      { programAddress: address("TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg") }
    )
  };
};
var resolveTakerTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === TokenStandard.ProgrammableNonFungible || args.tokenStandard === TokenStandard.ProgrammableNonFungibleEdition ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.takerTa?.value)
    })
  } : { value: null };
};
var resolveUserTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === TokenStandard.ProgrammableNonFungible || args.tokenStandard === TokenStandard.ProgrammableNonFungibleEdition ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(
        accounts.takerTa?.value ?? accounts.ownerTa?.value
      )
    })
  } : { value: null };
};
var resolveEdition = async ({
  accounts
}) => {
  return {
    value: await findEditionPda({
      mint: expectAddress(accounts.mint?.value)
    })
  };
};

// src/generated/types/authorizationDataLocal.ts
init_env_shim();
function getAuthorizationDataLocalEncoder() {
  return getStructEncoder([
    ["payload", getArrayEncoder(getTaggedPayloadEncoder())]
  ]);
}
function getAuthorizationDataLocalDecoder() {
  return getStructDecoder([
    ["payload", getArrayDecoder(getTaggedPayloadDecoder())]
  ]);
}
function getAuthorizationDataLocalCodec() {
  return combineCodec(
    getAuthorizationDataLocalEncoder(),
    getAuthorizationDataLocalDecoder()
  );
}

// src/generated/types/buySellEvent.ts
init_env_shim();
function getBuySellEventEncoder() {
  return getStructEncoder([
    ["currentPrice", getU64Encoder()],
    ["takerFee", getU64Encoder()],
    ["mmFee", getU64Encoder()],
    ["creatorsFee", getU64Encoder()]
  ]);
}
function getBuySellEventDecoder() {
  return getStructDecoder([
    ["currentPrice", getU64Decoder()],
    ["takerFee", getU64Decoder()],
    ["mmFee", getU64Decoder()],
    ["creatorsFee", getU64Decoder()]
  ]);
}
function getBuySellEventCodec() {
  return combineCodec(getBuySellEventEncoder(), getBuySellEventDecoder());
}

// src/generated/types/curveType.ts
init_env_shim();
var CurveType = /* @__PURE__ */ ((CurveType2) => {
  CurveType2[CurveType2["Linear"] = 0] = "Linear";
  CurveType2[CurveType2["Exponential"] = 1] = "Exponential";
  return CurveType2;
})(CurveType || {});
function getCurveTypeEncoder() {
  return getEnumEncoder(CurveType);
}
function getCurveTypeDecoder() {
  return getEnumDecoder(CurveType);
}
function getCurveTypeCodec() {
  return combineCodec(getCurveTypeEncoder(), getCurveTypeDecoder());
}

// src/generated/types/direction.ts
init_env_shim();
var Direction = /* @__PURE__ */ ((Direction2) => {
  Direction2[Direction2["Up"] = 0] = "Up";
  Direction2[Direction2["Down"] = 1] = "Down";
  return Direction2;
})(Direction || {});
function getDirectionEncoder() {
  return getEnumEncoder(Direction);
}
function getDirectionDecoder() {
  return getEnumDecoder(Direction);
}
function getDirectionCodec() {
  return combineCodec(getDirectionEncoder(), getDirectionDecoder());
}

// src/generated/types/editPoolConfig.ts
init_env_shim();
function getEditPoolConfigEncoder() {
  return getStructEncoder([
    ["curveType", getCurveTypeEncoder()],
    ["startingPrice", getU64Encoder()],
    ["delta", getU64Encoder()],
    ["mmCompoundFees", getBooleanEncoder()],
    ["mmFeeBps", getNullableU16Encoder()]
  ]);
}
function getEditPoolConfigDecoder() {
  return getStructDecoder([
    ["curveType", getCurveTypeDecoder()],
    ["startingPrice", getU64Decoder()],
    ["delta", getU64Decoder()],
    ["mmCompoundFees", getBooleanDecoder()],
    ["mmFeeBps", getNullableU16Decoder()]
  ]);
}
function getEditPoolConfigCodec() {
  return combineCodec(getEditPoolConfigEncoder(), getEditPoolConfigDecoder());
}

// src/generated/types/payloadTypeLocal.ts
init_env_shim();
function getPayloadTypeLocalEncoder() {
  return getDiscriminatedUnionEncoder([
    [
      "Pubkey",
      getStructEncoder([["fields", getTupleEncoder([getAddressEncoder()])]])
    ],
    [
      "Seeds",
      getStructEncoder([
        ["fields", getTupleEncoder([getSeedsVecLocalEncoder()])]
      ])
    ],
    [
      "MerkleProof",
      getStructEncoder([
        ["fields", getTupleEncoder([getProofInfoLocalEncoder()])]
      ])
    ],
    [
      "Number",
      getStructEncoder([["fields", getTupleEncoder([getU64Encoder()])]])
    ]
  ]);
}
function getPayloadTypeLocalDecoder() {
  return getDiscriminatedUnionDecoder([
    [
      "Pubkey",
      getStructDecoder([["fields", getTupleDecoder([getAddressDecoder()])]])
    ],
    [
      "Seeds",
      getStructDecoder([
        ["fields", getTupleDecoder([getSeedsVecLocalDecoder()])]
      ])
    ],
    [
      "MerkleProof",
      getStructDecoder([
        ["fields", getTupleDecoder([getProofInfoLocalDecoder()])]
      ])
    ],
    [
      "Number",
      getStructDecoder([["fields", getTupleDecoder([getU64Decoder()])]])
    ]
  ]);
}
function getPayloadTypeLocalCodec() {
  return combineCodec(
    getPayloadTypeLocalEncoder(),
    getPayloadTypeLocalDecoder()
  );
}
function payloadTypeLocal(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPayloadTypeLocal(kind, value) {
  return value.__kind === kind;
}

// src/generated/types/poolConfig.ts
init_env_shim();
function getPoolConfigEncoder() {
  return getStructEncoder([
    ["poolType", getPoolTypeEncoder()],
    ["curveType", getCurveTypeEncoder()],
    ["startingPrice", getU64Encoder()],
    ["delta", getU64Encoder()],
    ["mmCompoundFees", getBooleanEncoder()],
    ["mmFeeBps", getNullableU16Encoder()]
  ]);
}
function getPoolConfigDecoder() {
  return getStructDecoder([
    ["poolType", getPoolTypeDecoder()],
    ["curveType", getCurveTypeDecoder()],
    ["startingPrice", getU64Decoder()],
    ["delta", getU64Decoder()],
    ["mmCompoundFees", getBooleanDecoder()],
    ["mmFeeBps", getNullableU16Decoder()]
  ]);
}
function getPoolConfigCodec() {
  return combineCodec(getPoolConfigEncoder(), getPoolConfigDecoder());
}

// src/generated/types/poolStats.ts
init_env_shim();
function getPoolStatsEncoder() {
  return getStructEncoder([
    ["takerSellCount", getU32Encoder()],
    ["takerBuyCount", getU32Encoder()],
    ["accumulatedMmProfit", getU64Encoder()]
  ]);
}
function getPoolStatsDecoder() {
  return getStructDecoder([
    ["takerSellCount", getU32Decoder()],
    ["takerBuyCount", getU32Decoder()],
    ["accumulatedMmProfit", getU64Decoder()]
  ]);
}
function getPoolStatsCodec() {
  return combineCodec(getPoolStatsEncoder(), getPoolStatsDecoder());
}

// src/generated/types/poolType.ts
init_env_shim();
var PoolType = /* @__PURE__ */ ((PoolType2) => {
  PoolType2[PoolType2["Token"] = 0] = "Token";
  PoolType2[PoolType2["NFT"] = 1] = "NFT";
  PoolType2[PoolType2["Trade"] = 2] = "Trade";
  return PoolType2;
})(PoolType || {});
function getPoolTypeEncoder() {
  return getEnumEncoder(PoolType);
}
function getPoolTypeDecoder() {
  return getEnumDecoder(PoolType);
}
function getPoolTypeCodec() {
  return combineCodec(getPoolTypeEncoder(), getPoolTypeDecoder());
}

// src/generated/types/proofInfoLocal.ts
init_env_shim();
function getProofInfoLocalEncoder() {
  return getStructEncoder([
    ["proof", getArrayEncoder(fixEncoderSize(getBytesEncoder(), 32))]
  ]);
}
function getProofInfoLocalDecoder() {
  return getStructDecoder([
    ["proof", getArrayDecoder(fixDecoderSize(getBytesDecoder(), 32))]
  ]);
}
function getProofInfoLocalCodec() {
  return combineCodec(getProofInfoLocalEncoder(), getProofInfoLocalDecoder());
}

// src/generated/types/seedsVecLocal.ts
init_env_shim();
function getSeedsVecLocalEncoder() {
  return getStructEncoder([
    [
      "seeds",
      getArrayEncoder(addEncoderSizePrefix(getBytesEncoder(), getU32Encoder()))
    ]
  ]);
}
function getSeedsVecLocalDecoder() {
  return getStructDecoder([
    [
      "seeds",
      getArrayDecoder(addDecoderSizePrefix(getBytesDecoder(), getU32Decoder()))
    ]
  ]);
}
function getSeedsVecLocalCodec() {
  return combineCodec(getSeedsVecLocalEncoder(), getSeedsVecLocalDecoder());
}

// src/generated/types/taggedPayload.ts
init_env_shim();
function getTaggedPayloadEncoder() {
  return getStructEncoder([
    ["name", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
    ["payload", getPayloadTypeLocalEncoder()]
  ]);
}
function getTaggedPayloadDecoder() {
  return getStructDecoder([
    ["name", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["payload", getPayloadTypeLocalDecoder()]
  ]);
}
function getTaggedPayloadCodec() {
  return combineCodec(getTaggedPayloadEncoder(), getTaggedPayloadDecoder());
}

// src/generated/types/takerSide.ts
init_env_shim();
var TakerSide = /* @__PURE__ */ ((TakerSide2) => {
  TakerSide2[TakerSide2["Buy"] = 0] = "Buy";
  TakerSide2[TakerSide2["Sell"] = 1] = "Sell";
  return TakerSide2;
})(TakerSide || {});
function getTakerSideEncoder() {
  return getEnumEncoder(TakerSide);
}
function getTakerSideDecoder() {
  return getEnumDecoder(TakerSide);
}
function getTakerSideCodec() {
  return combineCodec(getTakerSideEncoder(), getTakerSideDecoder());
}

// src/generated/types/tAmmEvent.ts
init_env_shim();
function getTAmmEventEncoder() {
  return getDiscriminatedUnionEncoder([
    [
      "BuySellEvent",
      getStructEncoder([
        ["fields", getTupleEncoder([getBuySellEventEncoder()])]
      ])
    ]
  ]);
}
function getTAmmEventDecoder() {
  return getDiscriminatedUnionDecoder([
    [
      "BuySellEvent",
      getStructDecoder([
        ["fields", getTupleDecoder([getBuySellEventDecoder()])]
      ])
    ]
  ]);
}
function getTAmmEventCodec() {
  return combineCodec(getTAmmEventEncoder(), getTAmmEventDecoder());
}
function tAmmEvent(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isTAmmEvent(kind, value) {
  return value.__kind === kind;
}

// src/generated/types/transferDirection.ts
init_env_shim();
var TransferDirection = /* @__PURE__ */ ((TransferDirection2) => {
  TransferDirection2[TransferDirection2["IntoPool"] = 0] = "IntoPool";
  TransferDirection2[TransferDirection2["OutOfPool"] = 1] = "OutOfPool";
  return TransferDirection2;
})(TransferDirection || {});
function getTransferDirectionEncoder() {
  return getEnumEncoder(TransferDirection);
}
function getTransferDirectionDecoder() {
  return getEnumDecoder(TransferDirection);
}
function getTransferDirectionCodec() {
  return combineCodec(
    getTransferDirectionEncoder(),
    getTransferDirectionDecoder()
  );
}

// src/generated/accounts/pool.ts
var POOL_DISCRIMINATOR = new Uint8Array([
  241,
  154,
  109,
  4,
  17,
  177,
  109,
  188
]);
function getPoolDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(POOL_DISCRIMINATOR);
}
function getPoolEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["version", getU8Encoder()],
      ["bump", getArrayEncoder(getU8Encoder(), { size: 1 })],
      ["poolId", fixEncoderSize(getBytesEncoder(), 32)],
      ["createdAt", getI64Encoder()],
      ["updatedAt", getI64Encoder()],
      ["expiry", getI64Encoder()],
      ["owner", getAddressEncoder()],
      ["whitelist", getAddressEncoder()],
      ["rentPayer", getAddressEncoder()],
      ["currency", getCurrencyEncoder()],
      ["amount", getU64Encoder()],
      ["priceOffset", getI32Encoder()],
      ["nftsHeld", getU32Encoder()],
      ["stats", getPoolStatsEncoder()],
      ["sharedEscrow", getNullableAddressEncoder()],
      ["cosigner", getNullableAddressEncoder()],
      ["makerBroker", getNullableAddressEncoder()],
      ["maxTakerSellCount", getU32Encoder()],
      ["config", getPoolConfigEncoder()],
      ["reserved", getArrayEncoder(getU8Encoder(), { size: 100 })]
    ]),
    (value) => ({ ...value, discriminator: POOL_DISCRIMINATOR })
  );
}
function getPoolDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["version", getU8Decoder()],
    ["bump", getArrayDecoder(getU8Decoder(), { size: 1 })],
    ["poolId", fixDecoderSize(getBytesDecoder(), 32)],
    ["createdAt", getI64Decoder()],
    ["updatedAt", getI64Decoder()],
    ["expiry", getI64Decoder()],
    ["owner", getAddressDecoder()],
    ["whitelist", getAddressDecoder()],
    ["rentPayer", getAddressDecoder()],
    ["currency", getCurrencyDecoder()],
    ["amount", getU64Decoder()],
    ["priceOffset", getI32Decoder()],
    ["nftsHeld", getU32Decoder()],
    ["stats", getPoolStatsDecoder()],
    ["sharedEscrow", getNullableAddressDecoder()],
    ["cosigner", getNullableAddressDecoder()],
    ["makerBroker", getNullableAddressDecoder()],
    ["maxTakerSellCount", getU32Decoder()],
    ["config", getPoolConfigDecoder()],
    ["reserved", getArrayDecoder(getU8Decoder(), { size: 100 })]
  ]);
}
function getPoolCodec() {
  return combineCodec(getPoolEncoder(), getPoolDecoder());
}
function decodePool(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getPoolDecoder()
  );
}
async function fetchPool(rpc, address4, config) {
  const maybeAccount = await fetchMaybePool(rpc, address4, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybePool(rpc, address4, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address4, config);
  return decodePool(maybeAccount);
}
async function fetchAllPool(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybePool(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybePool(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodePool(maybeAccount));
}
function getPoolSize() {
  return 447;
}
async function fetchPoolFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybePoolFromSeeds(rpc, seeds, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybePoolFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address4] = await findPoolPda(seeds, { programAddress });
  return await fetchMaybePool(rpc, address4, fetchConfig);
}

// src/generated/errors/tensorAmm.ts
init_env_shim();

// src/generated/programs/tensorAmm.ts
init_env_shim();
var TENSOR_AMM_PROGRAM_ADDRESS = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
var TensorAmmAccount = /* @__PURE__ */ ((TensorAmmAccount2) => {
  TensorAmmAccount2[TensorAmmAccount2["AssetDepositReceipt"] = 0] = "AssetDepositReceipt";
  TensorAmmAccount2[TensorAmmAccount2["NftDepositReceipt"] = 1] = "NftDepositReceipt";
  TensorAmmAccount2[TensorAmmAccount2["Pool"] = 2] = "Pool";
  return TensorAmmAccount2;
})(TensorAmmAccount || {});
function identifyTensorAmmAccount(account) {
  const data = "data" in account ? account.data : account;
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([147, 18, 99, 58, 249, 8, 196, 221])
    ),
    0
  )) {
    return 0 /* AssetDepositReceipt */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([206, 255, 132, 254, 67, 78, 62, 96])
    ),
    0
  )) {
    return 1 /* NftDepositReceipt */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([241, 154, 109, 4, 17, 177, 109, 188])
    ),
    0
  )) {
    return 2 /* Pool */;
  }
  throw new Error(
    "The provided account could not be identified as a tensorAmm account."
  );
}
var TensorAmmInstruction = /* @__PURE__ */ ((TensorAmmInstruction2) => {
  TensorAmmInstruction2[TensorAmmInstruction2["TammNoop"] = 0] = "TammNoop";
  TensorAmmInstruction2[TensorAmmInstruction2["CreatePool"] = 1] = "CreatePool";
  TensorAmmInstruction2[TensorAmmInstruction2["EditPool"] = 2] = "EditPool";
  TensorAmmInstruction2[TensorAmmInstruction2["ClosePool"] = 3] = "ClosePool";
  TensorAmmInstruction2[TensorAmmInstruction2["CloseExpiredPool"] = 4] = "CloseExpiredPool";
  TensorAmmInstruction2[TensorAmmInstruction2["DepositSol"] = 5] = "DepositSol";
  TensorAmmInstruction2[TensorAmmInstruction2["WithdrawSol"] = 6] = "WithdrawSol";
  TensorAmmInstruction2[TensorAmmInstruction2["DepositNft"] = 7] = "DepositNft";
  TensorAmmInstruction2[TensorAmmInstruction2["WithdrawNft"] = 8] = "WithdrawNft";
  TensorAmmInstruction2[TensorAmmInstruction2["BuyNft"] = 9] = "BuyNft";
  TensorAmmInstruction2[TensorAmmInstruction2["SellNftTokenPool"] = 10] = "SellNftTokenPool";
  TensorAmmInstruction2[TensorAmmInstruction2["SellNftTradePool"] = 11] = "SellNftTradePool";
  TensorAmmInstruction2[TensorAmmInstruction2["DepositNftCore"] = 12] = "DepositNftCore";
  TensorAmmInstruction2[TensorAmmInstruction2["WithdrawNftCore"] = 13] = "WithdrawNftCore";
  TensorAmmInstruction2[TensorAmmInstruction2["BuyNftCore"] = 14] = "BuyNftCore";
  TensorAmmInstruction2[TensorAmmInstruction2["SellNftTokenPoolCore"] = 15] = "SellNftTokenPoolCore";
  TensorAmmInstruction2[TensorAmmInstruction2["SellNftTradePoolCore"] = 16] = "SellNftTradePoolCore";
  TensorAmmInstruction2[TensorAmmInstruction2["DepositNftT22"] = 17] = "DepositNftT22";
  TensorAmmInstruction2[TensorAmmInstruction2["WithdrawNftT22"] = 18] = "WithdrawNftT22";
  TensorAmmInstruction2[TensorAmmInstruction2["BuyNftT22"] = 19] = "BuyNftT22";
  TensorAmmInstruction2[TensorAmmInstruction2["SellNftTokenPoolT22"] = 20] = "SellNftTokenPoolT22";
  TensorAmmInstruction2[TensorAmmInstruction2["SellNftTradePoolT22"] = 21] = "SellNftTradePoolT22";
  return TensorAmmInstruction2;
})(TensorAmmInstruction || {});
function identifyTensorAmmInstruction(instruction) {
  const data = "data" in instruction ? instruction.data : instruction;
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([31, 162, 228, 158, 153, 160, 198, 182])
    ),
    0
  )) {
    return 0 /* TammNoop */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([233, 146, 209, 142, 207, 104, 64, 188])
    ),
    0
  )) {
    return 1 /* CreatePool */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([50, 174, 34, 36, 3, 166, 29, 204])
    ),
    0
  )) {
    return 2 /* EditPool */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([140, 189, 209, 23, 239, 62, 239, 11])
    ),
    0
  )) {
    return 3 /* ClosePool */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([108, 212, 233, 53, 132, 83, 63, 219])
    ),
    0
  )) {
    return 4 /* CloseExpiredPool */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([108, 81, 78, 117, 125, 155, 56, 200])
    ),
    0
  )) {
    return 5 /* DepositSol */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([145, 131, 74, 136, 65, 137, 42, 38])
    ),
    0
  )) {
    return 6 /* WithdrawSol */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([93, 226, 132, 166, 141, 9, 48, 101])
    ),
    0
  )) {
    return 7 /* DepositNft */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([142, 181, 191, 149, 82, 175, 216, 100])
    ),
    0
  )) {
    return 8 /* WithdrawNft */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([96, 0, 28, 190, 49, 107, 83, 222])
    ),
    0
  )) {
    return 9 /* BuyNft */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([57, 44, 192, 48, 83, 8, 107, 48])
    ),
    0
  )) {
    return 10 /* SellNftTokenPool */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([131, 82, 125, 77, 13, 157, 36, 90])
    ),
    0
  )) {
    return 11 /* SellNftTradePool */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([73, 21, 4, 64, 161, 214, 248, 77])
    ),
    0
  )) {
    return 12 /* DepositNftCore */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([112, 131, 239, 116, 187, 149, 114, 145])
    ),
    0
  )) {
    return 13 /* WithdrawNftCore */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([163, 102, 58, 107, 184, 4, 169, 121])
    ),
    0
  )) {
    return 14 /* BuyNftCore */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([137, 227, 197, 122, 245, 229, 56, 205])
    ),
    0
  )) {
    return 15 /* SellNftTokenPoolCore */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([37, 205, 141, 53, 86, 245, 45, 78])
    ),
    0
  )) {
    return 16 /* SellNftTradePoolCore */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([208, 34, 6, 147, 95, 218, 49, 160])
    ),
    0
  )) {
    return 17 /* DepositNftT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([112, 55, 80, 231, 181, 190, 92, 12])
    ),
    0
  )) {
    return 18 /* WithdrawNftT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([155, 219, 126, 245, 170, 199, 51, 79])
    ),
    0
  )) {
    return 19 /* BuyNftT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([149, 234, 31, 103, 26, 36, 166, 49])
    ),
    0
  )) {
    return 20 /* SellNftTokenPoolT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([124, 145, 23, 52, 72, 113, 85, 9])
    ),
    0
  )) {
    return 21 /* SellNftTradePoolT22 */;
  }
  throw new Error(
    "The provided instruction could not be identified as a tensorAmm instruction."
  );
}

// src/generated/errors/tensorAmm.ts
var TENSOR_AMM_ERROR__WRONG_WHITELIST = 12e3;
var TENSOR_AMM_ERROR__WRONG_POOL_TYPE = 12001;
var TENSOR_AMM_ERROR__FEES_TOO_HIGH = 12002;
var TENSOR_AMM_ERROR__DELTA_TOO_LARGE = 12003;
var TENSOR_AMM_ERROR__ARITHMETIC_ERROR = 12004;
var TENSOR_AMM_ERROR__PRICE_MISMATCH = 12005;
var TENSOR_AMM_ERROR__EXISTING_NFTS = 12006;
var TENSOR_AMM_ERROR__FEES_NOT_ALLOWED = 12007;
var TENSOR_AMM_ERROR__WRONG_POOL_VERSION = 12008;
var TENSOR_AMM_ERROR__BAD_MINT_PROOF = 12009;
var TENSOR_AMM_ERROR__WRONG_COSIGNER = 12010;
var TENSOR_AMM_ERROR__BAD_SHARED_ESCROW = 12011;
var TENSOR_AMM_ERROR__POOL_ON_SHARED_ESCROW = 12012;
var TENSOR_AMM_ERROR__CANNOT_USE_SHARED_ESCROW = 12013;
var TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_EXCEEDED = 12014;
var TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_TOO_SMALL = 12015;
var TENSOR_AMM_ERROR__STARTING_PRICE_TOO_SMALL = 12016;
var TENSOR_AMM_ERROR__POOL_INSUFFICIENT_RENT = 12017;
var TENSOR_AMM_ERROR__WRONG_RENT_PAYER = 12018;
var TENSOR_AMM_ERROR__EXPIRY_TOO_LARGE = 12019;
var TENSOR_AMM_ERROR__EXPIRED_POOL = 12020;
var TENSOR_AMM_ERROR__POOL_NOT_EXPIRED = 12021;
var TENSOR_AMM_ERROR__INVALID_POOL_AMOUNT = 12022;
var TENSOR_AMM_ERROR__WRONG_MAKER_BROKER = 12023;
var TENSOR_AMM_ERROR__WRONG_OWNER = 12024;
var TENSOR_AMM_ERROR__ESCROW_PROGRAM_NOT_SET = 12025;
var TENSOR_AMM_ERROR__MISSING_MAKER_BROKER = 12026;
var TENSOR_AMM_ERROR__MISSING_COSIGNER = 12027;
var TENSOR_AMM_ERROR__INVALID_EDITION = 12028;
var tensorAmmErrorMessages;
if (process.env.NODE_ENV !== "production") {
  tensorAmmErrorMessages = {
    [TENSOR_AMM_ERROR__ARITHMETIC_ERROR]: `arithmetic error`,
    [TENSOR_AMM_ERROR__BAD_MINT_PROOF]: `bad mint proof account`,
    [TENSOR_AMM_ERROR__BAD_SHARED_ESCROW]: `bad shared escrow account`,
    [TENSOR_AMM_ERROR__CANNOT_USE_SHARED_ESCROW]: `cannot use shared escrow in NFT pools`,
    [TENSOR_AMM_ERROR__DELTA_TOO_LARGE]: `delta too large`,
    [TENSOR_AMM_ERROR__ESCROW_PROGRAM_NOT_SET]: `Escrow program not set`,
    [TENSOR_AMM_ERROR__EXISTING_NFTS]: `cannot close pool with nfts in escrow -- withdraw all before closing`,
    [TENSOR_AMM_ERROR__EXPIRED_POOL]: `Expired Pool`,
    [TENSOR_AMM_ERROR__EXPIRY_TOO_LARGE]: `Expiry too large`,
    [TENSOR_AMM_ERROR__FEES_NOT_ALLOWED]: `fees not allowed for non-trade pools`,
    [TENSOR_AMM_ERROR__FEES_TOO_HIGH]: `fees entered above allowed threshold`,
    [TENSOR_AMM_ERROR__INVALID_EDITION]: `Invalid edition`,
    [TENSOR_AMM_ERROR__INVALID_POOL_AMOUNT]: `Invalid pool amount`,
    [TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_EXCEEDED]: `max taker sell count exceeded, pool cannot buy anymore NFTs`,
    [TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_TOO_SMALL]: `max taker sell count is too small`,
    [TENSOR_AMM_ERROR__MISSING_COSIGNER]: `Missing cosigner account`,
    [TENSOR_AMM_ERROR__MISSING_MAKER_BROKER]: `Missing maker broker account`,
    [TENSOR_AMM_ERROR__POOL_INSUFFICIENT_RENT]: `Pool must keep minimum rent balance`,
    [TENSOR_AMM_ERROR__POOL_NOT_EXPIRED]: `Pool not expired`,
    [TENSOR_AMM_ERROR__POOL_ON_SHARED_ESCROW]: `expected a non-shared escrow pool to be passed in`,
    [TENSOR_AMM_ERROR__PRICE_MISMATCH]: `specified price not within current price`,
    [TENSOR_AMM_ERROR__STARTING_PRICE_TOO_SMALL]: `starting price can't be smaller than 1 lamport`,
    [TENSOR_AMM_ERROR__WRONG_COSIGNER]: `wrong cosigner`,
    [TENSOR_AMM_ERROR__WRONG_MAKER_BROKER]: `Wrong maker broker account`,
    [TENSOR_AMM_ERROR__WRONG_OWNER]: `Wrong owner`,
    [TENSOR_AMM_ERROR__WRONG_POOL_TYPE]: `operation not permitted on this pool type`,
    [TENSOR_AMM_ERROR__WRONG_POOL_VERSION]: `wrong pool version provided`,
    [TENSOR_AMM_ERROR__WRONG_RENT_PAYER]: `Wrong rent payer`,
    [TENSOR_AMM_ERROR__WRONG_WHITELIST]: `wrong whitelist`
  };
}
function getTensorAmmErrorMessage(code) {
  if (process.env.NODE_ENV !== "production") {
    return tensorAmmErrorMessages[code];
  }
  return "Error message not available in production bundles.";
}
function isTensorAmmError(error, transactionMessage, code) {
  return isProgramError(
    error,
    transactionMessage,
    TENSOR_AMM_PROGRAM_ADDRESS,
    code
  );
}

// src/generated/instructions/buyNft.ts
init_env_shim();
var BUY_NFT_DISCRIMINATOR = new Uint8Array([
  96,
  0,
  28,
  190,
  49,
  107,
  83,
  222
]);
function getBuyNftDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(BUY_NFT_DISCRIMINATOR);
}
function getBuyNftInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: BUY_NFT_DISCRIMINATOR,
      authorizationData: value.authorizationData ?? none(),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none()
    })
  );
}
function getBuyNftInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())]
  ]);
}
function getBuyNftInstructionDataCodec() {
  return combineCodec(
    getBuyNftInstructionDataEncoder(),
    getBuyNftInstructionDataDecoder()
  );
}
async function getBuyNftInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEdition(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.takerTa.value) {
    accounts.takerTa = {
      ...accounts.takerTa,
      ...await resolveTakerAta(resolverScope)
    };
  }
  if (!accounts.userTokenRecord.value) {
    accounts.userTokenRecord = {
      ...accounts.userTokenRecord,
      ...await resolveUserTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyNftInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyNftInstruction(instruction) {
  if (instruction.accounts.length < 29) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      userTokenRecord: getNextOptionalAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      nftReceipt: getNextAccount(),
      takerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getBuyNftInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/buyNftCore.ts
init_env_shim();
var BUY_NFT_CORE_DISCRIMINATOR = new Uint8Array([
  163,
  102,
  58,
  107,
  184,
  4,
  169,
  121
]);
function getBuyNftCoreDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    BUY_NFT_CORE_DISCRIMINATOR
  );
}
function getBuyNftCoreInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: BUY_NFT_CORE_DISCRIMINATOR })
  );
}
function getBuyNftCoreInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()]
  ]);
}
function getBuyNftCoreInstructionDataCodec() {
  return combineCodec(
    getBuyNftCoreInstructionDataEncoder(),
    getBuyNftCoreInstructionDataDecoder()
  );
}
async function getBuyNftCoreInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findAssetDepositReceiptPda({
      asset: expectAddress(accounts.asset.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyNftCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyNftCoreInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyNftCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyNftCoreInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      mplCoreProgram: getNextAccount(),
      nftReceipt: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getBuyNftCoreInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/buyNftT22.ts
init_env_shim();
var BUY_NFT_T22_DISCRIMINATOR = new Uint8Array([
  155,
  219,
  126,
  245,
  170,
  199,
  51,
  79
]);
function getBuyNftT22DiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(BUY_NFT_T22_DISCRIMINATOR);
}
function getBuyNftT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: BUY_NFT_T22_DISCRIMINATOR })
  );
}
function getBuyNftT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()]
  ]);
}
function getBuyNftT22InstructionDataCodec() {
  return combineCodec(
    getBuyNftT22InstructionDataEncoder(),
    getBuyNftT22InstructionDataDecoder()
  );
}
async function getBuyNftT22InstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.takerTa.value) {
    accounts.takerTa = {
      ...accounts.takerTa,
      ...await resolveTakerAta(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address4) => ({
      address: address4,
      role: AccountRole.WRITABLE
    })),
    ...args.transferHookAccounts.map((address4) => ({
      address: address4,
      role: AccountRole.READONLY
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyNftT22Instruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address4) => ({
      address: address4,
      role: AccountRole.WRITABLE
    })),
    ...args.transferHookAccounts.map((address4) => ({
      address: address4,
      role: AccountRole.READONLY
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyNftT22Instruction(instruction) {
  if (instruction.accounts.length < 21) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      mint: getNextAccount(),
      nftReceipt: getNextAccount(),
      takerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getBuyNftT22InstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/closeExpiredPool.ts
init_env_shim();
var CLOSE_EXPIRED_POOL_DISCRIMINATOR = new Uint8Array([
  108,
  212,
  233,
  53,
  132,
  83,
  63,
  219
]);
function getCloseExpiredPoolDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    CLOSE_EXPIRED_POOL_DISCRIMINATOR
  );
}
function getCloseExpiredPoolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({ ...value, discriminator: CLOSE_EXPIRED_POOL_DISCRIMINATOR })
  );
}
function getCloseExpiredPoolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getCloseExpiredPoolInstructionDataCodec() {
  return combineCodec(
    getCloseExpiredPoolInstructionDataEncoder(),
    getCloseExpiredPoolInstructionDataDecoder()
  );
}
function getCloseExpiredPoolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCloseExpiredPoolInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCloseExpiredPoolInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      rentPayer: getNextAccount(),
      owner: getNextAccount(),
      pool: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getCloseExpiredPoolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/closePool.ts
init_env_shim();
var CLOSE_POOL_DISCRIMINATOR = new Uint8Array([
  140,
  189,
  209,
  23,
  239,
  62,
  239,
  11
]);
function getClosePoolDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(CLOSE_POOL_DISCRIMINATOR);
}
function getClosePoolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({ ...value, discriminator: CLOSE_POOL_DISCRIMINATOR })
  );
}
function getClosePoolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getClosePoolInstructionDataCodec() {
  return combineCodec(
    getClosePoolInstructionDataEncoder(),
    getClosePoolInstructionDataDecoder()
  );
}
function getClosePoolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectTransactionSigner(
      accounts.owner.value
    ).address;
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getClosePoolInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseClosePoolInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      rentPayer: getNextAccount(),
      owner: getNextAccount(),
      pool: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getClosePoolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/createPool.ts
init_env_shim();
var CREATE_POOL_DISCRIMINATOR = new Uint8Array([
  233,
  146,
  209,
  142,
  207,
  104,
  64,
  188
]);
function getCreatePoolDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(CREATE_POOL_DISCRIMINATOR);
}
function getCreatePoolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["poolId", fixEncoderSize(getBytesEncoder(), 32)],
      ["config", getPoolConfigEncoder()],
      ["currency", getOptionEncoder(getAddressEncoder())],
      ["cosigner", getOptionEncoder(getAddressEncoder())],
      ["makerBroker", getOptionEncoder(getAddressEncoder())],
      ["maxTakerSellCount", getOptionEncoder(getU32Encoder())],
      ["expireInSec", getOptionEncoder(getU64Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: CREATE_POOL_DISCRIMINATOR,
      currency: value.currency ?? none(),
      cosigner: value.cosigner ?? none(),
      makerBroker: value.makerBroker ?? none(),
      maxTakerSellCount: value.maxTakerSellCount ?? none(),
      expireInSec: value.expireInSec ?? none()
    })
  );
}
function getCreatePoolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["poolId", fixDecoderSize(getBytesDecoder(), 32)],
    ["config", getPoolConfigDecoder()],
    ["currency", getOptionDecoder(getAddressDecoder())],
    ["cosigner", getOptionDecoder(getAddressDecoder())],
    ["makerBroker", getOptionDecoder(getAddressDecoder())],
    ["maxTakerSellCount", getOptionDecoder(getU32Decoder())],
    ["expireInSec", getOptionDecoder(getU64Decoder())]
  ]);
}
function getCreatePoolInstructionDataCodec() {
  return combineCodec(
    getCreatePoolInstructionDataEncoder(),
    getCreatePoolInstructionDataDecoder()
  );
}
async function getCreatePoolInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!args.poolId) {
    args.poolId = resolvePoolIdOnCreate();
  }
  if (!accounts.pool.value) {
    accounts.pool.value = await findPoolPda({
      owner: expectAddress(accounts.owner.value),
      poolId: expectSome(args.poolId)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreatePoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getCreatePoolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!args.poolId) {
    args.poolId = resolvePoolIdOnCreate();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreatePoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreatePoolInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      rentPayer: getNextAccount(),
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      systemProgram: getNextAccount()
    },
    data: getCreatePoolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/depositNft.ts
init_env_shim();
var DEPOSIT_NFT_DISCRIMINATOR = new Uint8Array([
  93,
  226,
  132,
  166,
  141,
  9,
  48,
  101
]);
function getDepositNftDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(DEPOSIT_NFT_DISCRIMINATOR);
}
function getDepositNftInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: DEPOSIT_NFT_DISCRIMINATOR,
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getDepositNftInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getDepositNftInstructionDataCodec() {
  return combineCodec(
    getDepositNftInstructionDataEncoder(),
    getDepositNftInstructionDataDecoder()
  );
}
async function getDepositNftInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEdition(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.userTokenRecord.value) {
    accounts.userTokenRecord = {
      ...accounts.userTokenRecord,
      ...await resolveUserTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getDepositNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getDepositNftInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getDepositNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseDepositNftInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      userTokenRecord: getNextOptionalAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      nftReceipt: getNextAccount(),
      ownerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getDepositNftInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/depositNftCore.ts
init_env_shim();
var DEPOSIT_NFT_CORE_DISCRIMINATOR = new Uint8Array([
  73,
  21,
  4,
  64,
  161,
  214,
  248,
  77
]);
function getDepositNftCoreDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    DEPOSIT_NFT_CORE_DISCRIMINATOR
  );
}
function getDepositNftCoreInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({ ...value, discriminator: DEPOSIT_NFT_CORE_DISCRIMINATOR })
  );
}
function getDepositNftCoreInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getDepositNftCoreInstructionDataCodec() {
  return combineCodec(
    getDepositNftCoreInstructionDataEncoder(),
    getDepositNftCoreInstructionDataDecoder()
  );
}
async function getDepositNftCoreInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findAssetDepositReceiptPda({
      asset: expectAddress(accounts.asset.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getDepositNftCoreInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getDepositNftCoreInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getDepositNftCoreInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDepositNftCoreInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      mplCoreProgram: getNextAccount(),
      nftReceipt: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getDepositNftCoreInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/depositNftT22.ts
init_env_shim();
var DEPOSIT_NFT_T22_DISCRIMINATOR = new Uint8Array([
  208,
  34,
  6,
  147,
  95,
  218,
  49,
  160
]);
function getDepositNftT22DiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    DEPOSIT_NFT_T22_DISCRIMINATOR
  );
}
function getDepositNftT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({ ...value, discriminator: DEPOSIT_NFT_T22_DISCRIMINATOR })
  );
}
function getDepositNftT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getDepositNftT22InstructionDataCodec() {
  return combineCodec(
    getDepositNftT22InstructionDataEncoder(),
    getDepositNftT22InstructionDataDecoder()
  );
}
async function getDepositNftT22InstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = args.transferHookAccounts.map(
    (address4) => ({ address: address4, role: AccountRole.READONLY })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getDepositNftT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function getDepositNftT22Instruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = args.transferHookAccounts.map(
    (address4) => ({ address: address4, role: AccountRole.READONLY })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getDepositNftT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDepositNftT22Instruction(instruction) {
  if (instruction.accounts.length < 11) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      mint: getNextAccount(),
      nftReceipt: getNextAccount(),
      ownerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getDepositNftT22InstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/depositSol.ts
init_env_shim();
var DEPOSIT_SOL_DISCRIMINATOR = new Uint8Array([
  108,
  81,
  78,
  117,
  125,
  155,
  56,
  200
]);
function getDepositSolDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(DEPOSIT_SOL_DISCRIMINATOR);
}
function getDepositSolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["lamports", getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: DEPOSIT_SOL_DISCRIMINATOR })
  );
}
function getDepositSolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["lamports", getU64Decoder()]
  ]);
}
function getDepositSolInstructionDataCodec() {
  return combineCodec(
    getDepositSolInstructionDataEncoder(),
    getDepositSolInstructionDataDecoder()
  );
}
function getDepositSolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getDepositSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseDepositSolInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getDepositSolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/editPool.ts
init_env_shim();
var EDIT_POOL_DISCRIMINATOR = new Uint8Array([
  50,
  174,
  34,
  36,
  3,
  166,
  29,
  204
]);
function getEditPoolDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(EDIT_POOL_DISCRIMINATOR);
}
function getEditPoolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["newConfig", getOptionEncoder(getEditPoolConfigEncoder())],
      ["cosigner", getOptionEncoder(getAddressEncoder())],
      ["makerBroker", getOptionEncoder(getAddressEncoder())],
      ["expireInSec", getOptionEncoder(getU64Encoder())],
      ["maxTakerSellCount", getOptionEncoder(getU32Encoder())],
      ["resetPriceOffset", getBooleanEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: EDIT_POOL_DISCRIMINATOR,
      cosigner: value.cosigner ?? none(),
      makerBroker: value.makerBroker ?? none(),
      expireInSec: value.expireInSec ?? none(),
      maxTakerSellCount: value.maxTakerSellCount ?? none()
    })
  );
}
function getEditPoolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["newConfig", getOptionDecoder(getEditPoolConfigDecoder())],
    ["cosigner", getOptionDecoder(getAddressDecoder())],
    ["makerBroker", getOptionDecoder(getAddressDecoder())],
    ["expireInSec", getOptionDecoder(getU64Decoder())],
    ["maxTakerSellCount", getOptionDecoder(getU32Decoder())],
    ["resetPriceOffset", getBooleanDecoder()]
  ]);
}
function getEditPoolInstructionDataCodec() {
  return combineCodec(
    getEditPoolInstructionDataEncoder(),
    getEditPoolInstructionDataDecoder()
  );
}
function getEditPoolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    pool: { value: input.pool ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getEditPoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseEditPoolInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getEditPoolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/sellNftTokenPool.ts
init_env_shim();
var SELL_NFT_TOKEN_POOL_DISCRIMINATOR = new Uint8Array([
  57,
  44,
  192,
  48,
  83,
  8,
  107,
  48
]);
function getSellNftTokenPoolDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    SELL_NFT_TOKEN_POOL_DISCRIMINATOR
  );
}
function getSellNftTokenPoolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minPrice", getU64Encoder()],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: SELL_NFT_TOKEN_POOL_DISCRIMINATOR,
      authorizationData: value.authorizationData ?? none(),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none()
    })
  );
}
function getSellNftTokenPoolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minPrice", getU64Decoder()],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())]
  ]);
}
function getSellNftTokenPoolInstructionDataCodec() {
  return combineCodec(
    getSellNftTokenPoolInstructionDataEncoder(),
    getSellNftTokenPoolInstructionDataDecoder()
  );
}
async function getSellNftTokenPoolInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEdition(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.takerTa.value) {
    accounts.takerTa = {
      ...accounts.takerTa,
      ...await resolveTakerAta(resolverScope)
    };
  }
  if (!accounts.userTokenRecord.value) {
    accounts.userTokenRecord = {
      ...accounts.userTokenRecord,
      ...await resolveUserTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.ownerTokenRecord.value) {
    accounts.ownerTokenRecord = {
      ...accounts.ownerTokenRecord,
      ...await resolveOwnerTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTokenPoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellNftTokenPoolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTokenPoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellNftTokenPoolInstruction(instruction) {
  if (instruction.accounts.length < 30) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      userTokenRecord: getNextOptionalAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      takerTa: getNextAccount(),
      ownerTa: getNextAccount(),
      poolTa: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getSellNftTokenPoolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/sellNftTokenPoolCore.ts
init_env_shim();
var SELL_NFT_TOKEN_POOL_CORE_DISCRIMINATOR = new Uint8Array([
  137,
  227,
  197,
  122,
  245,
  229,
  56,
  205
]);
function getSellNftTokenPoolCoreDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    SELL_NFT_TOKEN_POOL_CORE_DISCRIMINATOR
  );
}
function getSellNftTokenPoolCoreInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minPrice", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: SELL_NFT_TOKEN_POOL_CORE_DISCRIMINATOR
    })
  );
}
function getSellNftTokenPoolCoreInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minPrice", getU64Decoder()]
  ]);
}
function getSellNftTokenPoolCoreInstructionDataCodec() {
  return combineCodec(
    getSellNftTokenPoolCoreInstructionDataEncoder(),
    getSellNftTokenPoolCoreInstructionDataDecoder()
  );
}
async function getSellNftTokenPoolCoreInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTokenPoolCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellNftTokenPoolCoreInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTokenPoolCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellNftTokenPoolCoreInstruction(instruction) {
  if (instruction.accounts.length < 17) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      mplCoreProgram: getNextAccount()
    },
    data: getSellNftTokenPoolCoreInstructionDataDecoder().decode(
      instruction.data
    )
  };
}

// src/generated/instructions/sellNftTokenPoolT22.ts
init_env_shim();
var SELL_NFT_TOKEN_POOL_T22_DISCRIMINATOR = new Uint8Array([
  149,
  234,
  31,
  103,
  26,
  36,
  166,
  49
]);
function getSellNftTokenPoolT22DiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    SELL_NFT_TOKEN_POOL_T22_DISCRIMINATOR
  );
}
function getSellNftTokenPoolT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minPrice", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: SELL_NFT_TOKEN_POOL_T22_DISCRIMINATOR
    })
  );
}
function getSellNftTokenPoolT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minPrice", getU64Decoder()]
  ]);
}
function getSellNftTokenPoolT22InstructionDataCodec() {
  return combineCodec(
    getSellNftTokenPoolT22InstructionDataEncoder(),
    getSellNftTokenPoolT22InstructionDataDecoder()
  );
}
async function getSellNftTokenPoolT22InstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.takerTa.value) {
    accounts.takerTa = {
      ...accounts.takerTa,
      ...await resolveTakerAta(resolverScope)
    };
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address4) => ({
      address: address4,
      role: AccountRole.WRITABLE
    })),
    ...args.transferHookAccounts.map((address4) => ({
      address: address4,
      role: AccountRole.READONLY
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTokenPoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellNftTokenPoolT22Instruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address4) => ({
      address: address4,
      role: AccountRole.WRITABLE
    })),
    ...args.transferHookAccounts.map((address4) => ({
      address: address4,
      role: AccountRole.READONLY
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTokenPoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellNftTokenPoolT22Instruction(instruction) {
  if (instruction.accounts.length < 20) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      mint: getNextAccount(),
      takerTa: getNextAccount(),
      ownerTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getSellNftTokenPoolT22InstructionDataDecoder().decode(
      instruction.data
    )
  };
}

// src/generated/instructions/sellNftTradePool.ts
init_env_shim();
var SELL_NFT_TRADE_POOL_DISCRIMINATOR = new Uint8Array([
  131,
  82,
  125,
  77,
  13,
  157,
  36,
  90
]);
function getSellNftTradePoolDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    SELL_NFT_TRADE_POOL_DISCRIMINATOR
  );
}
function getSellNftTradePoolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minPrice", getU64Encoder()],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: SELL_NFT_TRADE_POOL_DISCRIMINATOR,
      authorizationData: value.authorizationData ?? none(),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none()
    })
  );
}
function getSellNftTradePoolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minPrice", getU64Decoder()],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())]
  ]);
}
function getSellNftTradePoolInstructionDataCodec() {
  return combineCodec(
    getSellNftTradePoolInstructionDataEncoder(),
    getSellNftTradePoolInstructionDataDecoder()
  );
}
async function getSellNftTradePoolInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEdition(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.takerTa.value) {
    accounts.takerTa = {
      ...accounts.takerTa,
      ...await resolveTakerAta(resolverScope)
    };
  }
  if (!accounts.userTokenRecord.value) {
    accounts.userTokenRecord = {
      ...accounts.userTokenRecord,
      ...await resolveUserTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTradePoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellNftTradePoolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTradePoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellNftTradePoolInstruction(instruction) {
  if (instruction.accounts.length < 29) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      userTokenRecord: getNextOptionalAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      nftReceipt: getNextAccount(),
      takerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getSellNftTradePoolInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/sellNftTradePoolCore.ts
init_env_shim();
var SELL_NFT_TRADE_POOL_CORE_DISCRIMINATOR = new Uint8Array([
  37,
  205,
  141,
  53,
  86,
  245,
  45,
  78
]);
function getSellNftTradePoolCoreDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    SELL_NFT_TRADE_POOL_CORE_DISCRIMINATOR
  );
}
function getSellNftTradePoolCoreInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minPrice", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: SELL_NFT_TRADE_POOL_CORE_DISCRIMINATOR
    })
  );
}
function getSellNftTradePoolCoreInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minPrice", getU64Decoder()]
  ]);
}
function getSellNftTradePoolCoreInstructionDataCodec() {
  return combineCodec(
    getSellNftTradePoolCoreInstructionDataEncoder(),
    getSellNftTradePoolCoreInstructionDataDecoder()
  );
}
async function getSellNftTradePoolCoreInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findAssetDepositReceiptPda({
      asset: expectAddress(accounts.asset.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTradePoolCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellNftTradePoolCoreInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address4) => ({ address: address4, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTradePoolCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellNftTradePoolCoreInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      mplCoreProgram: getNextAccount(),
      nftReceipt: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getSellNftTradePoolCoreInstructionDataDecoder().decode(
      instruction.data
    )
  };
}

// src/generated/instructions/sellNftTradePoolT22.ts
init_env_shim();
var SELL_NFT_TRADE_POOL_T22_DISCRIMINATOR = new Uint8Array([
  124,
  145,
  23,
  52,
  72,
  113,
  85,
  9
]);
function getSellNftTradePoolT22DiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    SELL_NFT_TRADE_POOL_T22_DISCRIMINATOR
  );
}
function getSellNftTradePoolT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minPrice", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: SELL_NFT_TRADE_POOL_T22_DISCRIMINATOR
    })
  );
}
function getSellNftTradePoolT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minPrice", getU64Decoder()]
  ]);
}
function getSellNftTradePoolT22InstructionDataCodec() {
  return combineCodec(
    getSellNftTradePoolT22InstructionDataEncoder(),
    getSellNftTradePoolT22InstructionDataDecoder()
  );
}
async function getSellNftTradePoolT22InstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.takerTa.value) {
    accounts.takerTa = {
      ...accounts.takerTa,
      ...await resolveTakerAta(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address4) => ({
      address: address4,
      role: AccountRole.WRITABLE
    })),
    ...args.transferHookAccounts.map((address4) => ({
      address: address4,
      role: AccountRole.READONLY
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTradePoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellNftTradePoolT22Instruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    nativeProgram: { value: input.nativeProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    takerTa: { value: input.takerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram = {
      ...accounts.escrowProgram,
      ...resolveEscrowProgramFromSharedEscrow(resolverScope)
    };
  }
  if (!accounts.nativeProgram.value) {
    accounts.nativeProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address4) => ({
      address: address4,
      role: AccountRole.WRITABLE
    })),
    ...args.transferHookAccounts.map((address4) => ({
      address: address4,
      role: AccountRole.READONLY
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.nativeProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.takerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellNftTradePoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellNftTradePoolT22Instruction(instruction) {
  if (instruction.accounts.length < 21) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      taker: getNextAccount(),
      rentPayer: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      escrowProgram: getNextOptionalAccount(),
      nativeProgram: getNextAccount(),
      mint: getNextAccount(),
      nftReceipt: getNextAccount(),
      takerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getSellNftTradePoolT22InstructionDataDecoder().decode(
      instruction.data
    )
  };
}

// src/generated/instructions/tammNoop.ts
init_env_shim();
var TAMM_NOOP_DISCRIMINATOR = new Uint8Array([
  31,
  162,
  228,
  158,
  153,
  160,
  198,
  182
]);
function getTammNoopDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(TAMM_NOOP_DISCRIMINATOR);
}
function getTammNoopInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["event", getTAmmEventEncoder()]
    ]),
    (value) => ({ ...value, discriminator: TAMM_NOOP_DISCRIMINATOR })
  );
}
function getTammNoopInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["event", getTAmmEventDecoder()]
  ]);
}
function getTammNoopInstructionDataCodec() {
  return combineCodec(
    getTammNoopInstructionDataEncoder(),
    getTammNoopInstructionDataDecoder()
  );
}
function getTammNoopInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    pool: { value: input.pool ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [getAccountMeta(accounts.pool)],
    programAddress,
    data: getTammNoopInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammNoopInstruction(instruction) {
  if (instruction.accounts.length < 1) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      pool: getNextAccount()
    },
    data: getTammNoopInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/withdrawNft.ts
init_env_shim();
var WITHDRAW_NFT_DISCRIMINATOR = new Uint8Array([
  142,
  181,
  191,
  149,
  82,
  175,
  216,
  100
]);
function getWithdrawNftDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    WITHDRAW_NFT_DISCRIMINATOR
  );
}
function getWithdrawNftInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: WITHDRAW_NFT_DISCRIMINATOR,
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getWithdrawNftInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getWithdrawNftInstructionDataCodec() {
  return combineCodec(
    getWithdrawNftInstructionDataEncoder(),
    getWithdrawNftInstructionDataDecoder()
  );
}
async function getWithdrawNftInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEdition(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.userTokenRecord.value) {
    accounts.userTokenRecord = {
      ...accounts.userTokenRecord,
      ...await resolveUserTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getWithdrawNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawNftInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    userTokenRecord: { value: input.userTokenRecord ?? null, isWritable: true },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.userTokenRecord),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getWithdrawNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawNftInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      userTokenRecord: getNextOptionalAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      nftReceipt: getNextAccount(),
      ownerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getWithdrawNftInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/withdrawNftCore.ts
init_env_shim();
var WITHDRAW_NFT_CORE_DISCRIMINATOR = new Uint8Array([
  112,
  131,
  239,
  116,
  187,
  149,
  114,
  145
]);
function getWithdrawNftCoreDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    WITHDRAW_NFT_CORE_DISCRIMINATOR
  );
}
function getWithdrawNftCoreInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({ ...value, discriminator: WITHDRAW_NFT_CORE_DISCRIMINATOR })
  );
}
function getWithdrawNftCoreInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getWithdrawNftCoreInstructionDataCodec() {
  return combineCodec(
    getWithdrawNftCoreInstructionDataEncoder(),
    getWithdrawNftCoreInstructionDataDecoder()
  );
}
async function getWithdrawNftCoreInstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findAssetDepositReceiptPda({
      asset: expectAddress(accounts.asset.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt)
    ],
    programAddress,
    data: getWithdrawNftCoreInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getWithdrawNftCoreInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.nftReceipt)
    ],
    programAddress,
    data: getWithdrawNftCoreInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseWithdrawNftCoreInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      mplCoreProgram: getNextAccount(),
      nftReceipt: getNextAccount()
    },
    data: getWithdrawNftCoreInstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/withdrawNftT22.ts
init_env_shim();
var WITHDRAW_NFT_T22_DISCRIMINATOR = new Uint8Array([
  112,
  55,
  80,
  231,
  181,
  190,
  92,
  12
]);
function getWithdrawNftT22DiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    WITHDRAW_NFT_T22_DISCRIMINATOR
  );
}
function getWithdrawNftT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({ ...value, discriminator: WITHDRAW_NFT_T22_DISCRIMINATOR })
  );
}
function getWithdrawNftT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getWithdrawNftT22InstructionDataCodec() {
  return combineCodec(
    getWithdrawNftT22InstructionDataEncoder(),
    getWithdrawNftT22InstructionDataDecoder()
  );
}
async function getWithdrawNftT22InstructionAsync(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.nftReceipt.value) {
    accounts.nftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = args.transferHookAccounts.map(
    (address4) => ({ address: address4, role: AccountRole.READONLY })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getWithdrawNftT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function getWithdrawNftT22Instruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    nftReceipt: { value: input.nftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = args.transferHookAccounts.map(
    (address4) => ({ address: address4, role: AccountRole.READONLY })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getWithdrawNftT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseWithdrawNftT22Instruction(instruction) {
  if (instruction.accounts.length < 11) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_AMM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      whitelist: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      mint: getNextAccount(),
      nftReceipt: getNextAccount(),
      ownerTa: getNextAccount(),
      poolTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getWithdrawNftT22InstructionDataDecoder().decode(instruction.data)
  };
}

// src/generated/instructions/withdrawSol.ts
init_env_shim();
var WITHDRAW_SOL_DISCRIMINATOR = new Uint8Array([
  145,
  131,
  74,
  136,
  65,
  137,
  42,
  38
]);
function getWithdrawSolDiscriminatorBytes() {
  return fixEncoderSize(getBytesEncoder(), 8).encode(
    WITHDRAW_SOL_DISCRIMINATOR
  );
}
function getWithdrawSolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["lamports", getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: WITHDRAW_SOL_DISCRIMINATOR })
  );
}
function getWithdrawSolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["lamports", getU64Decoder()]
  ]);
}
function getWithdrawSolInstructionDataCodec() {
  return combineCodec(
    getWithdrawSolInstructionDataEncoder(),
    getWithdrawSolInstructionDataDecoder()
  );
}
function getWithdrawSolInstruction(input, config) {
  const programAddress = config?.programAddress ?? TENSOR_AMM_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getWithdrawSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawSolInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      pool: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getWithdrawSolInstructionDataDecoder().decode(instruction.data)
  };
}

export { ASSET_DEPOSIT_RECEIPT_DISCRIMINATOR, BUY_NFT_CORE_DISCRIMINATOR, BUY_NFT_DISCRIMINATOR, BUY_NFT_T22_DISCRIMINATOR, CLOSE_EXPIRED_POOL_DISCRIMINATOR, CLOSE_POOL_DISCRIMINATOR, CREATE_POOL_DISCRIMINATOR, CurveType, DEFAULT_ADDRESS, DEPOSIT_NFT_CORE_DISCRIMINATOR, DEPOSIT_NFT_DISCRIMINATOR, DEPOSIT_NFT_T22_DISCRIMINATOR, DEPOSIT_SOL_DISCRIMINATOR, Direction, EDIT_POOL_DISCRIMINATOR, NFT_DEPOSIT_RECEIPT_DISCRIMINATOR, POOL_DISCRIMINATOR, PoolType, SELL_NFT_TOKEN_POOL_CORE_DISCRIMINATOR, SELL_NFT_TOKEN_POOL_DISCRIMINATOR, SELL_NFT_TOKEN_POOL_T22_DISCRIMINATOR, SELL_NFT_TRADE_POOL_CORE_DISCRIMINATOR, SELL_NFT_TRADE_POOL_DISCRIMINATOR, SELL_NFT_TRADE_POOL_T22_DISCRIMINATOR, TAMM_NOOP_DISCRIMINATOR, TENSOR_AMM_ERROR__ARITHMETIC_ERROR, TENSOR_AMM_ERROR__BAD_MINT_PROOF, TENSOR_AMM_ERROR__BAD_SHARED_ESCROW, TENSOR_AMM_ERROR__CANNOT_USE_SHARED_ESCROW, TENSOR_AMM_ERROR__DELTA_TOO_LARGE, TENSOR_AMM_ERROR__ESCROW_PROGRAM_NOT_SET, TENSOR_AMM_ERROR__EXISTING_NFTS, TENSOR_AMM_ERROR__EXPIRED_POOL, TENSOR_AMM_ERROR__EXPIRY_TOO_LARGE, TENSOR_AMM_ERROR__FEES_NOT_ALLOWED, TENSOR_AMM_ERROR__FEES_TOO_HIGH, TENSOR_AMM_ERROR__INVALID_EDITION, TENSOR_AMM_ERROR__INVALID_POOL_AMOUNT, TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_EXCEEDED, TENSOR_AMM_ERROR__MAX_TAKER_SELL_COUNT_TOO_SMALL, TENSOR_AMM_ERROR__MISSING_COSIGNER, TENSOR_AMM_ERROR__MISSING_MAKER_BROKER, TENSOR_AMM_ERROR__POOL_INSUFFICIENT_RENT, TENSOR_AMM_ERROR__POOL_NOT_EXPIRED, TENSOR_AMM_ERROR__POOL_ON_SHARED_ESCROW, TENSOR_AMM_ERROR__PRICE_MISMATCH, TENSOR_AMM_ERROR__STARTING_PRICE_TOO_SMALL, TENSOR_AMM_ERROR__WRONG_COSIGNER, TENSOR_AMM_ERROR__WRONG_MAKER_BROKER, TENSOR_AMM_ERROR__WRONG_OWNER, TENSOR_AMM_ERROR__WRONG_POOL_TYPE, TENSOR_AMM_ERROR__WRONG_POOL_VERSION, TENSOR_AMM_ERROR__WRONG_RENT_PAYER, TENSOR_AMM_ERROR__WRONG_WHITELIST, TENSOR_AMM_PROGRAM_ADDRESS, TakerSide, TensorAmmAccount, TensorAmmInstruction, TransferDirection, WITHDRAW_NFT_CORE_DISCRIMINATOR, WITHDRAW_NFT_DISCRIMINATOR, WITHDRAW_NFT_T22_DISCRIMINATOR, WITHDRAW_SOL_DISCRIMINATOR, calculateAmountForQuantity, calculatePrice, decodeAssetDepositReceipt, decodeNftDepositReceipt, decodePool, fetchAllAssetDepositReceipt, fetchAllMaybeAssetDepositReceipt, fetchAllMaybeNftDepositReceipt, fetchAllMaybePool, fetchAllNftDepositReceipt, fetchAllPool, fetchAssetDepositReceipt, fetchAssetDepositReceiptFromSeeds, fetchMaybeAssetDepositReceipt, fetchMaybeAssetDepositReceiptFromSeeds, fetchMaybeNftDepositReceipt, fetchMaybeNftDepositReceiptFromSeeds, fetchMaybePool, fetchMaybePoolFromSeeds, fetchNftDepositReceipt, fetchNftDepositReceiptFromSeeds, fetchPool, fetchPoolFromSeeds, findAssetDepositReceiptPda, findNftDepositReceiptPda, findPoolPda, getAmountOfBids, getAssetDepositReceiptCodec, getAssetDepositReceiptDecoder, getAssetDepositReceiptDiscriminatorBytes, getAssetDepositReceiptEncoder, getAssetDepositReceiptSize, getAuthorizationDataLocalCodec, getAuthorizationDataLocalDecoder, getAuthorizationDataLocalEncoder, getBuyNftCoreDiscriminatorBytes, getBuyNftCoreInstruction, getBuyNftCoreInstructionAsync, getBuyNftCoreInstructionDataCodec, getBuyNftCoreInstructionDataDecoder, getBuyNftCoreInstructionDataEncoder, getBuyNftDiscriminatorBytes, getBuyNftInstruction, getBuyNftInstructionAsync, getBuyNftInstructionDataCodec, getBuyNftInstructionDataDecoder, getBuyNftInstructionDataEncoder, getBuyNftT22DiscriminatorBytes, getBuyNftT22Instruction, getBuyNftT22InstructionAsync, getBuyNftT22InstructionDataCodec, getBuyNftT22InstructionDataDecoder, getBuyNftT22InstructionDataEncoder, getBuySellEventCodec, getBuySellEventDecoder, getBuySellEventEncoder, getCloseExpiredPoolDiscriminatorBytes, getCloseExpiredPoolInstruction, getCloseExpiredPoolInstructionDataCodec, getCloseExpiredPoolInstructionDataDecoder, getCloseExpiredPoolInstructionDataEncoder, getClosePoolDiscriminatorBytes, getClosePoolInstruction, getClosePoolInstructionDataCodec, getClosePoolInstructionDataDecoder, getClosePoolInstructionDataEncoder, getCreatePoolDiscriminatorBytes, getCreatePoolInstruction, getCreatePoolInstructionAsync, getCreatePoolInstructionDataCodec, getCreatePoolInstructionDataDecoder, getCreatePoolInstructionDataEncoder, getCurrencyCodec, getCurrencyDecoder, getCurrencyEncoder, getCurrentAskPrice, getCurrentBidPrice, getCurrentBidPriceSync, getCurveTypeCodec, getCurveTypeDecoder, getCurveTypeEncoder, getDepositNftCoreDiscriminatorBytes, getDepositNftCoreInstruction, getDepositNftCoreInstructionAsync, getDepositNftCoreInstructionDataCodec, getDepositNftCoreInstructionDataDecoder, getDepositNftCoreInstructionDataEncoder, getDepositNftDiscriminatorBytes, getDepositNftInstruction, getDepositNftInstructionAsync, getDepositNftInstructionDataCodec, getDepositNftInstructionDataDecoder, getDepositNftInstructionDataEncoder, getDepositNftT22DiscriminatorBytes, getDepositNftT22Instruction, getDepositNftT22InstructionAsync, getDepositNftT22InstructionDataCodec, getDepositNftT22InstructionDataDecoder, getDepositNftT22InstructionDataEncoder, getDepositSolDiscriminatorBytes, getDepositSolInstruction, getDepositSolInstructionDataCodec, getDepositSolInstructionDataDecoder, getDepositSolInstructionDataEncoder, getDirectionCodec, getDirectionDecoder, getDirectionEncoder, getEditPoolConfigCodec, getEditPoolConfigDecoder, getEditPoolConfigEncoder, getEditPoolDiscriminatorBytes, getEditPoolInstruction, getEditPoolInstructionDataCodec, getEditPoolInstructionDataDecoder, getEditPoolInstructionDataEncoder, getNftDepositReceiptCodec, getNftDepositReceiptDecoder, getNftDepositReceiptDiscriminatorBytes, getNftDepositReceiptEncoder, getNftDepositReceiptSize, getNullableAddressCodec, getNullableAddressDecoder, getNullableAddressEncoder, getNullableU16Codec, getNullableU16Decoder, getNullableU16Encoder, getPayloadTypeLocalCodec, getPayloadTypeLocalDecoder, getPayloadTypeLocalEncoder, getPoolCodec, getPoolConfigCodec, getPoolConfigDecoder, getPoolConfigEncoder, getPoolDecoder, getPoolDiscriminatorBytes, getPoolEncoder, getPoolSize, getPoolStatsCodec, getPoolStatsDecoder, getPoolStatsEncoder, getPoolTypeCodec, getPoolTypeDecoder, getPoolTypeEncoder, getProofInfoLocalCodec, getProofInfoLocalDecoder, getProofInfoLocalEncoder, getSeedsVecLocalCodec, getSeedsVecLocalDecoder, getSeedsVecLocalEncoder, getSellNftTokenPoolCoreDiscriminatorBytes, getSellNftTokenPoolCoreInstruction, getSellNftTokenPoolCoreInstructionAsync, getSellNftTokenPoolCoreInstructionDataCodec, getSellNftTokenPoolCoreInstructionDataDecoder, getSellNftTokenPoolCoreInstructionDataEncoder, getSellNftTokenPoolDiscriminatorBytes, getSellNftTokenPoolInstruction, getSellNftTokenPoolInstructionAsync, getSellNftTokenPoolInstructionDataCodec, getSellNftTokenPoolInstructionDataDecoder, getSellNftTokenPoolInstructionDataEncoder, getSellNftTokenPoolT22DiscriminatorBytes, getSellNftTokenPoolT22Instruction, getSellNftTokenPoolT22InstructionAsync, getSellNftTokenPoolT22InstructionDataCodec, getSellNftTokenPoolT22InstructionDataDecoder, getSellNftTokenPoolT22InstructionDataEncoder, getSellNftTradePoolCoreDiscriminatorBytes, getSellNftTradePoolCoreInstruction, getSellNftTradePoolCoreInstructionAsync, getSellNftTradePoolCoreInstructionDataCodec, getSellNftTradePoolCoreInstructionDataDecoder, getSellNftTradePoolCoreInstructionDataEncoder, getSellNftTradePoolDiscriminatorBytes, getSellNftTradePoolInstruction, getSellNftTradePoolInstructionAsync, getSellNftTradePoolInstructionDataCodec, getSellNftTradePoolInstructionDataDecoder, getSellNftTradePoolInstructionDataEncoder, getSellNftTradePoolT22DiscriminatorBytes, getSellNftTradePoolT22Instruction, getSellNftTradePoolT22InstructionAsync, getSellNftTradePoolT22InstructionDataCodec, getSellNftTradePoolT22InstructionDataDecoder, getSellNftTradePoolT22InstructionDataEncoder, getTAmmEventCodec, getTAmmEventDecoder, getTAmmEventEncoder, getTaggedPayloadCodec, getTaggedPayloadDecoder, getTaggedPayloadEncoder, getTakerSideCodec, getTakerSideDecoder, getTakerSideEncoder, getTammNoopDiscriminatorBytes, getTammNoopInstruction, getTammNoopInstructionDataCodec, getTammNoopInstructionDataDecoder, getTammNoopInstructionDataEncoder, getTensorAmmErrorMessage, getTransferDirectionCodec, getTransferDirectionDecoder, getTransferDirectionEncoder, getWithdrawNftCoreDiscriminatorBytes, getWithdrawNftCoreInstruction, getWithdrawNftCoreInstructionAsync, getWithdrawNftCoreInstructionDataCodec, getWithdrawNftCoreInstructionDataDecoder, getWithdrawNftCoreInstructionDataEncoder, getWithdrawNftDiscriminatorBytes, getWithdrawNftInstruction, getWithdrawNftInstructionAsync, getWithdrawNftInstructionDataCodec, getWithdrawNftInstructionDataDecoder, getWithdrawNftInstructionDataEncoder, getWithdrawNftT22DiscriminatorBytes, getWithdrawNftT22Instruction, getWithdrawNftT22InstructionAsync, getWithdrawNftT22InstructionDataCodec, getWithdrawNftT22InstructionDataDecoder, getWithdrawNftT22InstructionDataEncoder, getWithdrawSolDiscriminatorBytes, getWithdrawSolInstruction, getWithdrawSolInstructionDataCodec, getWithdrawSolInstructionDataDecoder, getWithdrawSolInstructionDataEncoder, identifyTensorAmmAccount, identifyTensorAmmInstruction, isPayloadTypeLocal, isSol, isTAmmEvent, isTensorAmmError, parseBuyNftCoreInstruction, parseBuyNftInstruction, parseBuyNftT22Instruction, parseCloseExpiredPoolInstruction, parseClosePoolInstruction, parseCreatePoolInstruction, parseDepositNftCoreInstruction, parseDepositNftInstruction, parseDepositNftT22Instruction, parseDepositSolInstruction, parseEditPoolInstruction, parseSellNftTokenPoolCoreInstruction, parseSellNftTokenPoolInstruction, parseSellNftTokenPoolT22Instruction, parseSellNftTradePoolCoreInstruction, parseSellNftTradePoolInstruction, parseSellNftTradePoolT22Instruction, parseTammNoopInstruction, parseWithdrawNftCoreInstruction, parseWithdrawNftInstruction, parseWithdrawNftT22Instruction, parseWithdrawSolInstruction, payloadTypeLocal, resolveEdition, resolveFeeVaultPdaFromPool, resolvePoolAssetReceipt, resolvePoolIdOnCreate, resolveTakerAta, resolveTakerTokenRecordFromTokenStandard, resolveUserTokenRecordFromTokenStandard, solCurrency, tAmmEvent };
//# sourceMappingURL=index.mjs.map
//# sourceMappingURL=index.mjs.map